
class RomajiWord:
    
    __slots__ = ("hiragana", "katakana")

    def __init__(self, hiragana, katakana):
        self.hiragana = hiragana
        self.katakana = katakana


romajitable = [
  [" ", "・", "・"],
  [",", "、", "、"],
  ["-", "ー", "ー"],
  [".", "。", "。"],
  ["\\ ", " ", " "],
  ["\\,", ",", ","],
  ["\\.", ".", "."],
  ["\\[", "[", "["],
  ["\\\\", "\\", "\\"],
  ["\\]", "]", "]"],
  ["a", "あ", "ア"],
  ["aa", "ああ", "アー"],
  ["b", "ぶ", "ブ"],
  ["ba", "ば", "バ"],
  ["bb", "っぶ", "ッブ"],
  ["bba", "っば", "ッバ"],
  ["bbaa", "っばあ", "ッバー"],
  ["bbe", "っべ", "ッベ"],
  ["bbee", "っべえ", "ッベー"],
  ["bbi", "っび", "ッビ"],
  ["bbii", "っびい", "ッビー"],
  ["bbo", "っぼ", "ッボ"],
  ["bboo", "っぼお", "ッボー"],
  ["bbou", "っぼう", "ッボー"],
  ["bbu", "っぶ", "ッブ"],
  ["bbuu", "っぶう", "ッブー"],
  ["bbya", "っびゃ", "ッビャ"],
  ["bbyaa", "っびゃあ", "ッビャー"],
  ["bbye", "っびぇ", "ッビェ"],
  ["bbyee", "っびぇえ", "ッビェー"],
  ["bbyi", "っびぃ", "ッビィ"],
  ["bbyii", "っびぃい", "ッビィー"],
  ["bbyo", "っびょ", "ッビョ"],
  ["bbyoo", "っびょお", "ッビョー"],
  ["bbyou", "っびょう", "ッビョー"],
  ["bbyu", "っびゅ", "ッビュ"],
  ["bbyuu", "っびゅう", "ッビュー"],
  ["bbyâ", "っびゃあ", "ッビャー"],
  ["bbyê", "っびぇえ", "ッビェー"],
  ["bbyî", "っびぃい", "ッビィー"],
  ["bbyô", "っびょう", "ッビョー"],
  ["bbyû", "っびゅう", "ッビュー"],
  ["bbyā", "っびゃあ", "ッビャー"],
  ["bbyē", "っびぇえ", "ッビェー"],
  ["bbyī", "っびぃい", "ッビィー"],
  ["bbyō", "っびょう", "ッビョー"],
  ["bbyū", "っびゅう", "ッビュー"],
  ["bbâ", "っばあ", "ッバー"],
  ["bbê", "っべえ", "ッベー"],
  ["bbî", "っびい", "ッビー"],
  ["bbô", "っぼう", "ッボー"],
  ["bbû", "っぶう", "ッブー"],
  ["bbā", "っばあ", "ッバー"],
  ["bbē", "っべえ", "ッベー"],
  ["bbī", "っびい", "ッビー"],
  ["bbō", "っぼう", "ッボー"],
  ["bbū", "っぶう", "ッブー"],
  ["be", "べ", "ベ"],
  ["bee", "べえ", "ベー"],
  ["bi", "び", "ビ"],
  ["bii", "びい", "ビー"],
  ["bo", "ぼ", "ボ"],
  ["boo", "ぼお", "ボー"],
  ["bou", "ぼう", "ボー"],
  ["bu", "ぶ", "ブ"],
  ["buu", "ぶう", "ブー"],
  ["bya", "びゃ", "ビャ"],
  ["byaa", "びゃあ", "ビャー"],
  ["bye", "びぇ", "ビェ"],
  ["byee", "びぇえ", "ビェー"],
  ["byi", "びぃ", "ビィ"],
  ["byii", "びぃい", "ビィー"],
  ["byo", "びょ", "ビョ"],
  ["byoo", "びょお", "ビョー"],
  ["byou", "びょう", "ビョー"],
  ["byu", "びゅ", "ビュ"],
  ["byuu", "びゅう", "ビュー"],
  ["byâ", "びゃあ", "ビャー"],
  ["byê", "びぇえ", "ビェー"],
  ["byî", "びぃい", "ビィー"],
  ["byô", "びょう", "ビョー"],
  ["byû", "びゅう", "ビュー"],
  ["byā", "びゃあ", "ビャー"],
  ["byē", "びぇえ", "ビェー"],
  ["byī", "びぃい", "ビィー"],
  ["byō", "びょう", "ビョー"],
  ["byū", "びゅう", "ビュー"],
  ["bâ", "ばあ", "バー"],
  ["bê", "べえ", "ベー"],
  ["bî", "びい", "ビー"],
  ["bô", "ぼう", "ボー"],
  ["bû", "ぶう", "ブー"],
  ["bā", "ばあ", "バー"],
  ["bē", "べえ", "ベー"],
  ["bī", "びい", "ビー"],
  ["bō", "ぼう", "ボー"],
  ["bū", "ぶう", "ブー"],
  ["c", "く", "ク"],
  ["cc", "っく", "ック"],
  ["ccha", "っちゃ", "ッチャ"],
  ["cchaa", "っちゃあ", "ッチャー"],
  ["cche", "っちぇ", "ッチェ"],
  ["cchee", "っちぇえ", "ッチェエ"],
  ["cchi", "っち", "ッチ"],
  ["cchii", "っちい", "ッチー"],
  ["ccho", "っちょ", "ッチョ"],
  ["cchoo", "っちょお", "ッチョー"],
  ["cchou", "っちょう", "ッチョー"],
  ["cchu", "っちゅ", "ッチュ"],
  ["cchuu", "っちゅう", "ッチュー"],
  ["cchâ", "っちゃあ", "ッチャー"],
  ["cchê", "っちぇえ", "ッチェエ"],
  ["cchî", "っちい", "ッチー"],
  ["cchô", "っちょう", "ッチョー"],
  ["cchû", "っちゅう", "ッチュー"],
  ["cchā", "っちゃあ", "ッチャー"],
  ["cchē", "っちぇえ", "ッチェエ"],
  ["cchī", "っちい", "ッチー"],
  ["cchō", "っちょう", "ッチョー"],
  ["cchū", "っちゅう", "ッチュー"],
  ["cha", "ちゃ", "チャ"],
  ["chaa", "ちゃあ", "チャー"],
  ["che", "ちぇ", "チェ"],
  ["chee", "ちぇえ", "チェエ"],
  ["chi", "ち", "チ"],
  ["chii", "ちい", "チー"],
  ["cho", "ちょ", "チョ"],
  ["choo", "ちょお", "チョー"],
  ["chou", "ちょう", "チョー"],
  ["chu", "ちゅ", "チュ"],
  ["chuu", "ちゅう", "チュー"],
  ["châ", "ちゃあ", "チャー"],
  ["chê", "ちぇえ", "チェエ"],
  ["chî", "ちい", "チー"],
  ["chô", "ちょう", "チョー"],
  ["chû", "ちゅう", "チュー"],
  ["chā", "ちゃあ", "チャー"],
  ["chē", "ちぇえ", "チェエ"],
  ["chī", "ちい", "チー"],
  ["chō", "ちょう", "チョー"],
  ["chū", "ちゅう", "チュー"],
  ["ck", "っく", "ック"],
  ["cka", "っか", "ッカ"],
  ["ckaa", "っかあ", "ッカー"],
  ["cke", "っけ", "ッケ"],
  ["ckee", "っけえ", "ッケー"],
  ["cki", "っき", "ッキ"],
  ["ckii", "っきい", "ッキー"],
  ["cko", "っこ", "ッコ"],
  ["ckoo", "っこお", "ッコー"],
  ["ckou", "っこう", "ッコー"],
  ["cku", "っく", "ック"],
  ["ckuu", "っくう", "ックー"],
  ["ckwa", "っくぁ", "ックァ"],
  ["ckwaa", "っくぁあ", "ックァー"],
  ["ckwe", "っくぇ", "ックェ"],
  ["ckwee", "っくぇえ", "ックェー"],
  ["ckwi", "っくぃ", "ックィ"],
  ["ckwii", "っくぃい", "ックィー"],
  ["ckwo", "っくぉ", "ックォ"],
  ["ckwoo", "っくぉお", "ックォー"],
  ["ckwou", "っくぉう", "ックォー"],
  ["ckwu", "っくぅ", "ックゥ"],
  ["ckwuu", "っくぅう", "ックゥー"],
  ["ckwâ", "っくぁあ", "ックァー"],
  ["ckwê", "っくぇえ", "ックェー"],
  ["ckwî", "っくぃい", "ックィー"],
  ["ckwô", "っくぉう", "ックォー"],
  ["ckwû", "っくぅう", "ックゥー"],
  ["ckwā", "っくぁあ", "ックァー"],
  ["ckwē", "っくぇえ", "ックェー"],
  ["ckwī", "っくぃい", "ックィー"],
  ["ckwō", "っくぉう", "ックォー"],
  ["ckwū", "っくぅう", "ックゥー"],
  ["ckya", "っきゃ", "ッキャ"],
  ["ckyaa", "っきゃあ", "ッキャー"],
  ["ckye", "っきぇ", "ッキェ"],
  ["ckyee", "っきぇえ", "ッキェー"],
  ["ckyi", "っきぃ", "ッキィ"],
  ["ckyii", "っきぃい", "ッキィー"],
  ["ckyo", "っきょ", "ッキョ"],
  ["ckyoo", "っきょお", "ッキョー"],
  ["ckyou", "っきょう", "ッキョー"],
  ["ckyu", "っきゅ", "ッキュ"],
  ["ckyuu", "っきゅう", "ッキュー"],
  ["ckyâ", "っきゃあ", "ッキャー"],
  ["ckyê", "っきぇえ", "ッキェー"],
  ["ckyî", "っきぃい", "ッキィー"],
  ["ckyô", "っきょう", "ッキョー"],
  ["ckyû", "っきゅう", "ッキュー"],
  ["ckyā", "っきゃあ", "ッキャー"],
  ["ckyē", "っきぇえ", "ッキェー"],
  ["ckyī", "っきぃい", "ッキィー"],
  ["ckyō", "っきょう", "ッキョー"],
  ["ckyū", "っきゅう", "ッキュー"],
  ["ckâ", "っかあ", "ッカー"],
  ["ckê", "っけえ", "ッケー"],
  ["ckî", "っきい", "ッキー"],
  ["ckô", "っこう", "ッコー"],
  ["ckû", "っくう", "ックー"],
  ["ckā", "っかあ", "ッカー"],
  ["ckē", "っけえ", "ッケー"],
  ["ckī", "っきい", "ッキー"],
  ["ckō", "っこう", "ッコー"],
  ["ckū", "っくう", "ックー"],
  ["d", "ど", "ド"],
  ["da", "だ", "ダ"],
  ["daa", "だあ", "ダー"],
  ["dd", "っど", "ッド"],
  ["dda", "っだ", "ッダ"],
  ["ddaa", "っだあ", "ッダー"],
  ["dde", "っで", "ッデ"],
  ["ddee", "っでえ", "ッデー"],
  ["ddja", "っぢゃ", "ッヂャ"],
  ["ddjaa", "っぢゃあ", "ッヂャー"],
  ["ddje", "っぢぇ", "ッヂェ"],
  ["ddjee", "っぢぇえ", "ッヂェー"],
  ["ddji", "っぢ", "ッヂ"],
  ["ddjii", "っぢい", "ッヂー"],
  ["ddjo", "っぢょ", "ッヂョ"],
  ["ddjoo", "っぢょお", "ッヂョー"],
  ["ddjou", "っぢょう", "ッヂョー"],
  ["ddju", "っぢゅ", "ッヂュ"],
  ["ddjuu", "っぢゅう", "ッヂュー"],
  ["ddjâ", "っぢゃあ", "ッヂャー"],
  ["ddjê", "っぢぇえ", "ッヂェー"],
  ["ddjî", "っぢい", "ッヂー"],
  ["ddjô", "っぢょう", "ッヂョー"],
  ["ddjû", "っぢゅう", "ッヂュー"],
  ["ddjā", "っぢゃあ", "ッヂャー"],
  ["ddjē", "っぢぇえ", "ッヂェー"],
  ["ddjī", "っぢい", "ッヂー"],
  ["ddjō", "っぢょう", "ッヂョー"],
  ["ddjū", "っぢゅう", "ッヂュー"],
  ["ddo", "っど", "ッド"],
  ["ddoo", "っどお", "ッドー"],
  ["ddou", "っどう", "ッドー"],
  ["ddya", "っぢゃ", "ッヂャ"],
  ["ddyaa", "っぢゃあ", "ッヂャー"],
  ["ddye", "っぢぇ", "ッヂェ"],
  ["ddyee", "っぢぇえ", "ッヂェー"],
  ["ddyi", "っぢ", "ッヂ"],
  ["ddyii", "っぢい", "ッヂー"],
  ["ddyo", "っぢょ", "ッヂョ"],
  ["ddyoo", "っぢょお", "ッヂョー"],
  ["ddyou", "っぢょう", "ッヂョー"],
  ["ddyu", "っぢゅ", "ッヂュ"],
  ["ddyuu", "っぢゅう", "ッヂュー"],
  ["ddyâ", "っぢゃあ", "ッヂャー"],
  ["ddyê", "っぢぇえ", "ッヂェー"],
  ["ddyî", "っぢい", "ッヂー"],
  ["ddyô", "っぢょう", "ッヂョー"],
  ["ddyû", "っぢゅう", "ッヂュー"],
  ["ddyā", "っぢゃあ", "ッヂャー"],
  ["ddyē", "っぢぇえ", "ッヂェー"],
  ["ddyī", "っぢい", "ッヂー"],
  ["ddyō", "っぢょう", "ッヂョー"],
  ["ddyū", "っぢゅう", "ッヂュー"],
  ["ddza", "っぢゃ", "っぢゃ"],
  ["ddzaa", "っぢゃあ", "っぢゃー"],
  ["ddze", "っぢぇ", "ッヂェ"],
  ["ddzee", "っぢぇえ", "ッヂェー"],
  ["ddzi", "っぢ", "ッヂ"],
  ["ddzii", "っぢい", "ッヂー"],
  ["ddzo", "っぢょ", "ッヂョ"],
  ["ddzoo", "っぢょお", "ッヂョー"],
  ["ddzou", "っぢょう", "ッヂョー"],
  ["ddzu", "っづ", "ッヅ"],
  ["ddzuu", "っづう", "ッヅー"],
  ["ddzâ", "っぢゃあ", "っぢゃー"],
  ["ddzê", "っぢぇえ", "ッヂェー"],
  ["ddzî", "っぢい", "ッヂー"],
  ["ddzô", "っぢょう", "ッヂョー"],
  ["ddzû", "っづう", "ッヅー"],
  ["ddzā", "っぢゃあ", "っぢゃー"],
  ["ddzē", "っぢぇえ", "ッヂェー"],
  ["ddzī", "っぢい", "ッヂー"],
  ["ddzō", "っぢょう", "ッヂョー"],
  ["ddzū", "っづう", "ッヅー"],
  ["ddâ", "っだあ", "ッダー"],
  ["ddê", "っでえ", "ッデー"],
  ["ddô", "っどう", "ッドー"],
  ["ddā", "っだあ", "ッダー"],
  ["ddē", "っでえ", "ッデー"],
  ["ddō", "っどう", "ッドー"],
  ["de", "で", "デ"],
  ["dee", "でえ", "デー"],
  ["di", "でぃ", "ディ"],
  ["dii", "でぃい", "ディー"],
  ["dja", "ぢゃ", "ヂャ"],
  ["djaa", "ぢゃあ", "ヂャア"],
  ["dje", "ぢぇ", "ヂェ"],
  ["djee", "ぢぇえ", "ヂェー"],
  ["dji", "ぢ", "ヂ"],
  ["djii", "ぢい", "ヂー"],
  ["djo", "ぢょ", "ヂョ"],
  ["djoo", "ぢょお", "ヂョー"],
  ["djou", "ぢょう", "ヂョー"],
  ["dju", "ぢゅ", "ヂュ"],
  ["djuu", "ぢゅう", "ヂュー"],
  ["djâ", "ぢゃあ", "ヂャア"],
  ["djê", "ぢぇえ", "ヂェー"],
  ["djî", "ぢい", "ヂー"],
  ["djô", "ぢょう", "ヂョー"],
  ["djû", "ぢゅう", "ヂュー"],
  ["djā", "ぢゃあ", "ヂャア"],
  ["djē", "ぢぇえ", "ヂェー"],
  ["djī", "ぢい", "ヂー"],
  ["djō", "ぢょう", "ヂョー"],
  ["djū", "ぢゅう", "ヂュー"],
  ["do", "ど", "ド"],
  ["doo", "どお", "ドー"],
  ["dou", "どう", "ドー"],
  ["du", "どぅ", "ドゥ"],
  ["duu", "どぅう", "ドゥー"],
  ["dya", "ぢゃ", "ヂャ"],
  ["dyaa", "ぢゃあ", "ヂャア"],
  ["dye", "ぢぇ", "ヂェ"],
  ["dyee", "ぢぇえ", "ヂェー"],
  ["dyi", "ぢ", "ヂ"],
  ["dyii", "ぢい", "ヂー"],
  ["dyo", "ぢょ", "ヂョ"],
  ["dyoo", "ぢょお", "ヂョー"],
  ["dyou", "ぢょう", "ヂョー"],
  ["dyu", "ぢゅ", "ヂュ"],
  ["dyuu", "ぢゅう", "ヂュー"],
  ["dyâ", "ぢゃあ", "ヂャア"],
  ["dyê", "ぢぇえ", "ヂェー"],
  ["dyî", "ぢい", "ヂー"],
  ["dyô", "ぢょう", "ヂョー"],
  ["dyû", "ぢゅう", "ヂュー"],
  ["dyā", "ぢゃあ", "ヂャア"],
  ["dyē", "ぢぇえ", "ヂェー"],
  ["dyī", "ぢい", "ヂー"],
  ["dyō", "ぢょう", "ヂョー"],
  ["dyū", "ぢゅう", "ヂュー"],
  ["dza", "ぢゃ", "ヂャ"],
  ["dzaa", "ぢゃあ", "ヂャア"],
  ["dze", "ぢぇ", "ヂェ"],
  ["dzee", "ぢぇえ", "ヂェー"],
  ["dzi", "ぢ", "ヂ"],
  ["dzii", "ぢい", "ヂー"],
  ["dzo", "ぢょ", "ヂョ"],
  ["dzoo", "ぢょお", "ヂョー"],
  ["dzou", "ぢょう", "ヂョー"],
  ["dzu", "づ", "ヅ"],
  ["dzuu", "づう", "ヅー"],
  ["dzâ", "ぢゃあ", "ヂャア"],
  ["dzê", "ぢぇえ", "ヂェー"],
  ["dzî", "ぢい", "ヂー"],
  ["dzô", "ぢょう", "ヂョー"],
  ["dzû", "づう", "ヅー"],
  ["dzā", "ぢゃあ", "ヂャア"],
  ["dzē", "ぢぇえ", "ヂェー"],
  ["dzī", "ぢい", "ヂー"],
  ["dzō", "ぢょう", "ヂョー"],
  ["dzū", "づう", "ヅー"],
  ["dâ", "だあ", "ダー"],
  ["dê", "でえ", "デー"],
  ["dî", "でぃい", "ディー"],
  ["dô", "どう", "ドー"],
  ["dû", "どぅう", "ドゥー"],
  ["dā", "だあ", "ダー"],
  ["dē", "でえ", "デー"],
  ["dī", "でぃい", "ディー"],
  ["dō", "どう", "ドー"],
  ["dū", "どぅう", "ドゥー"],
  ["e", "え", "エ"],
  ["ee", "ええ", "エー"],
  ["f", "ふ", "フ"],
  ["fa", "ふぁ", "ファ"],
  ["faa", "ふぁあ", "ファー"],
  ["fe", "ふぇ", "フェ"],
  ["fee", "ふぇえ", "フェー"],
  ["ff", "っふ", "ッフ"],
  ["ffa", "っふぁ", "ッファ"],
  ["ffaa", "っふぁあ", "ッファー"],
  ["ffe", "っふぇ", "ッフェ"],
  ["ffee", "っふぇえ", "ッフェー"],
  ["ffi", "っふぃ", "ッフィ"],
  ["ffii", "っふぃい", "ッフィー"],
  ["ffo", "っふぉ", "ッフォ"],
  ["ffoo", "っふぉお", "ッフォー"],
  ["ffou", "っふぉう", "ッフォー"],
  ["ffu", "っふ", "ッフ"],
  ["ffuu", "っふう", "ッフー"],
  ["ffya", "っふゃ", "ッフャ"],
  ["ffyaa", "っふゃあ", "ッフャー"],
  ["ffye", "っふぇ", "ッフェ"],
  ["ffyee", "っふぇえ", "ッフェー"],
  ["ffyi", "っふぃ", "ッフィ"],
  ["ffyii", "っふぃい", "ッフィー"],
  ["ffyo", "っふょ", "ッフョ"],
  ["ffyoo", "っふょお", "ッフョー"],
  ["ffyou", "っふょう", "ッフョー"],
  ["ffyu", "っふゅ", "ッフュ"],
  ["ffyuu", "っふゅう", "ッフュー"],
  ["ffyâ", "っふゃあ", "ッフャー"],
  ["ffyê", "っふぇえ", "ッフェー"],
  ["ffyî", "っふぃい", "ッフィー"],
  ["ffyô", "っふょう", "ッフョー"],
  ["ffyû", "っふゅう", "ッフュー"],
  ["ffyā", "っふゃあ", "ッフャー"],
  ["ffyē", "っふぇえ", "ッフェー"],
  ["ffyī", "っふぃい", "ッフィー"],
  ["ffyō", "っふょう", "ッフョー"],
  ["ffyū", "っふゅう", "ッフュー"],
  ["ffâ", "っふぁあ", "ッファー"],
  ["ffê", "っふぇえ", "ッフェー"],
  ["ffî", "っふぃい", "ッフィー"],
  ["ffô", "っふぉう", "ッフォー"],
  ["ffû", "っふう", "ッフー"],
  ["ffā", "っふぁあ", "ッファー"],
  ["ffē", "っふぇえ", "ッフェー"],
  ["ffī", "っふぃい", "ッフィー"],
  ["ffō", "っふぉう", "ッフォー"],
  ["ffū", "っふう", "ッフー"],
  ["fi", "ふぃ", "フィ"],
  ["fii", "ふぃい", "フィー"],
  ["fo", "ふぉ", "フォ"],
  ["foo", "ふぉお", "フォー"],
  ["fou", "ふぉう", "フォー"],
  ["fu", "ふ", "フ"],
  ["fuu", "ふう", "フー"],
  ["fya", "ふゃ", "フャ"],
  ["fyaa", "ふゃあ", "フャー"],
  ["fye", "ふぇ", "フェ"],
  ["fyee", "ふぇえ", "フェー"],
  ["fyi", "ふぃ", "フィ"],
  ["fyii", "ふぃい", "フィー"],
  ["fyo", "ふょ", "フョ"],
  ["fyoo", "ふょお", "フョー"],
  ["fyou", "ふょう", "フョー"],
  ["fyu", "ふゅ", "フュ"],
  ["fyuu", "ふゅう", "フュー"],
  ["fyâ", "ふゃあ", "フャー"],
  ["fyê", "ふぇえ", "フェー"],
  ["fyî", "ふぃい", "フィー"],
  ["fyô", "ふょう", "フョー"],
  ["fyû", "ふゅう", "フュー"],
  ["fyā", "ふゃあ", "フャー"],
  ["fyē", "ふぇえ", "フェー"],
  ["fyī", "ふぃい", "フィー"],
  ["fyō", "ふょう", "フョー"],
  ["fyū", "ふゅう", "フュー"],
  ["fâ", "ふぁあ", "ファー"],
  ["fê", "ふぇえ", "フェー"],
  ["fî", "ふぃい", "フィー"],
  ["fô", "ふぉう", "フォー"],
  ["fû", "ふう", "フー"],
  ["fā", "ふぁあ", "ファー"],
  ["fē", "ふぇえ", "フェー"],
  ["fī", "ふぃい", "フィー"],
  ["fō", "ふぉう", "フォー"],
  ["fū", "ふう", "フー"],
  ["g", "ぐ", "グ"],
  ["ga", "が", "ガ"],
  ["gaa", "があ", "ガー"],
  ["ge", "げ", "ゲ"],
  ["gee", "げえ", "ゲー"],
  ["gg", "っぐ", "ッグ"],
  ["gga", "っが", "ッガ"],
  ["ggaa", "っがあ", "ッガー"],
  ["gge", "っげ", "ッゲ"],
  ["ggee", "っげえ", "ッゲー"],
  ["ggi", "っぎ", "ッギ"],
  ["ggii", "っぎい", "ッギー"],
  ["ggo", "っご", "ッゴ"],
  ["ggoo", "っごお", "ッゴー"],
  ["ggou", "っごう", "ッゴー"],
  ["ggu", "っぐ", "ッグ"],
  ["gguu", "っぐう", "ッグー"],
  ["ggwa", "っぐぁ", "ッグァ"],
  ["ggwaa", "っぐぁあ", "ッグァー"],
  ["ggwe", "っぐぇ", "ッグェ"],
  ["ggwee", "っぐぇえ", "ッグェー"],
  ["ggwi", "っぐぃ", "ッグィ"],
  ["ggwii", "っぐぃい", "ッグィー"],
  ["ggwo", "っぐぉ", "ッグォ"],
  ["ggwoo", "っぐぉお", "ッグォー"],
  ["ggwou", "っぐぉう", "ッグォー"],
  ["ggwu", "っぐぅ", "ッグゥ"],
  ["ggwuu", "っぐぅう", "ッグゥー"],
  ["ggwâ", "っぐぁあ", "ッグァー"],
  ["ggwê", "っぐぇえ", "ッグェー"],
  ["ggwî", "っぐぃい", "ッグィー"],
  ["ggwô", "っぐぉう", "ッグォー"],
  ["ggwû", "っぐぅう", "ッグゥー"],
  ["ggwā", "っぐぁあ", "ッグァー"],
  ["ggwē", "っぐぇえ", "ッグェー"],
  ["ggwī", "っぐぃい", "ッグィー"],
  ["ggwō", "っぐぉう", "ッグォー"],
  ["ggwū", "っぐぅう", "ッグゥー"],
  ["ggya", "っぎゃ", "ッギャ"],
  ["ggyaa", "っぎゃあ", "ッギャー"],
  ["ggye", "っぎぇ", "ッギェ"],
  ["ggyee", "っぎぇえ", "ッギェー"],
  ["ggyi", "っぎぃ", "ッギィ"],
  ["ggyii", "っぎぃい", "ッギィー"],
  ["ggyo", "っぎょ", "ッギョ"],
  ["ggyoo", "っぎょお", "ッギョー"],
  ["ggyou", "っぎょう", "ッギョー"],
  ["ggyu", "っぎゅ", "ッギュ"],
  ["ggyuu", "っぎゅう", "ッギュー"],
  ["ggyâ", "っぎゃあ", "ッギャー"],
  ["ggyê", "っぎぇえ", "ッギェー"],
  ["ggyî", "っぎぃい", "ッギィー"],
  ["ggyô", "っぎょう", "ッギョー"],
  ["ggyû", "っぎゅう", "ッギュー"],
  ["ggyā", "っぎゃあ", "ッギャー"],
  ["ggyē", "っぎぇえ", "ッギェー"],
  ["ggyī", "っぎぃい", "ッギィー"],
  ["ggyō", "っぎょう", "ッギョー"],
  ["ggyū", "っぎゅう", "ッギュー"],
  ["ggâ", "っがあ", "ッガー"],
  ["ggê", "っげえ", "ッゲー"],
  ["ggî", "っぎい", "ッギー"],
  ["ggô", "っごう", "ッゴー"],
  ["ggû", "っぐう", "ッグー"],
  ["ggā", "っがあ", "ッガー"],
  ["ggē", "っげえ", "ッゲー"],
  ["ggī", "っぎい", "ッギー"],
  ["ggō", "っごう", "ッゴー"],
  ["ggū", "っぐう", "ッグー"],
  ["gi", "ぎ", "ギ"],
  ["gii", "ぎい", "ギー"],
  ["go", "ご", "ゴ"],
  ["goo", "ごお", "ゴー"],
  ["gou", "ごう", "ゴー"],
  ["gu", "ぐ", "グ"],
  ["guu", "ぐう", "グー"],
  ["gwa", "ぐぁ", "グァ"],
  ["gwaa", "ぐぁあ", "グァー"],
  ["gwe", "ぐぇ", "グェ"],
  ["gwee", "ぐぇえ", "グェー"],
  ["gwi", "ぐぃ", "グィ"],
  ["gwii", "ぐぃい", "グィー"],
  ["gwo", "ぐぉ", "グォ"],
  ["gwoo", "ぐぉお", "グォー"],
  ["gwou", "ぐぉう", "グォー"],
  ["gwu", "ぐぅ", "グゥ"],
  ["gwuu", "ぐぅう", "グゥー"],
  ["gwâ", "ぐぁあ", "グァー"],
  ["gwê", "ぐぇえ", "グェー"],
  ["gwî", "ぐぃい", "グィー"],
  ["gwô", "ぐぉう", "グォー"],
  ["gwû", "ぐぅう", "グゥー"],
  ["gwā", "ぐぁあ", "グァー"],
  ["gwē", "ぐぇえ", "グェー"],
  ["gwī", "ぐぃい", "グィー"],
  ["gwō", "ぐぉう", "グォー"],
  ["gwū", "ぐぅう", "グゥー"],
  ["gya", "ぎゃ", "ギャ"],
  ["gyaa", "ぎゃあ", "ギャー"],
  ["gye", "ぎぇ", "ギェ"],
  ["gyee", "ぎぇえ", "ギェー"],
  ["gyi", "ぎぃ", "ギィ"],
  ["gyii", "ぎぃい", "ギィー"],
  ["gyo", "ぎょ", "ギョ"],
  ["gyoo", "ぎょお", "ギョー"],
  ["gyou", "ぎょう", "ギョー"],
  ["gyu", "ぎゅ", "ギュ"],
  ["gyuu", "ぎゅう", "ギュー"],
  ["gyâ", "ぎゃあ", "ギャー"],
  ["gyê", "ぎぇえ", "ギェー"],
  ["gyî", "ぎぃい", "ギィー"],
  ["gyô", "ぎょう", "ギョー"],
  ["gyû", "ぎゅう", "ギュー"],
  ["gyā", "ぎゃあ", "ギャー"],
  ["gyē", "ぎぇえ", "ギェー"],
  ["gyī", "ぎぃい", "ギィー"],
  ["gyō", "ぎょう", "ギョー"],
  ["gyū", "ぎゅう", "ギュー"],
  ["gâ", "があ", "ガー"],
  ["gê", "げえ", "ゲー"],
  ["gî", "ぎい", "ギー"],
  ["gô", "ごう", "ゴー"],
  ["gû", "ぐう", "グー"],
  ["gā", "があ", "ガー"],
  ["gē", "げえ", "ゲー"],
  ["gī", "ぎい", "ギー"],
  ["gō", "ごう", "ゴー"],
  ["gū", "ぐう", "グー"],
  ["h", "ほ", "ホ"],
  ["ha", "は", "ハ"],
  ["haa", "はあ", "ハー"],
  ["he", "へ", "ヘ"],
  ["hee", "へえ", "ヘー"],
  ["hh", "っほ", "ッホ"],
  ["hha", "っは", "ッハ"],
  ["hhaa", "っはあ", "ッハー"],
  ["hhe", "っへ", "ッヘ"],
  ["hhee", "っへえ", "ッヘー"],
  ["hhi", "っひ", "ッヒ"],
  ["hhii", "っひい", "ッヒー"],
  ["hho", "っほ", "ッホ"],
  ["hhoo", "っほお", "ッホー"],
  ["hhou", "っほう", "ッホー"],
  ["hhu", "っふ", "ッフ"],
  ["hhuu", "っふう", "ッフー"],
  ["hhya", "っひゃ", "ッヒャ"],
  ["hhyaa", "っひゃあ", "ッヒャー"],
  ["hhye", "っひぇ", "ッヒェ"],
  ["hhyee", "っひぇえ", "ッヒェー"],
  ["hhyi", "っひぃ", "ッヒィ"],
  ["hhyii", "っひぃい", "ッヒィー"],
  ["hhyo", "っひょ", "ッヒョ"],
  ["hhyoo", "っひょお", "ッヒョー"],
  ["hhyou", "っひょう", "ッヒョー"],
  ["hhyu", "っひゅ", "ッヒュ"],
  ["hhyuu", "っひゅう", "ッヒュー"],
  ["hhyâ", "っひゃあ", "ッヒャー"],
  ["hhyê", "っひぇえ", "ッヒェー"],
  ["hhyî", "っひぃい", "ッヒィー"],
  ["hhyô", "っひょう", "ッヒョー"],
  ["hhyû", "っひゅう", "ッヒュー"],
  ["hhyā", "っひゃあ", "ッヒャー"],
  ["hhyē", "っひぇえ", "ッヒェー"],
  ["hhyī", "っひぃい", "ッヒィー"],
  ["hhyō", "っひょう", "ッヒョー"],
  ["hhyū", "っひゅう", "ッヒュー"],
  ["hhâ", "っはあ", "ッハー"],
  ["hhê", "っへえ", "ッヘー"],
  ["hhî", "っひい", "ッヒー"],
  ["hhô", "っほう", "ッホー"],
  ["hhû", "っふう", "ッフー"],
  ["hhā", "っはあ", "ッハー"],
  ["hhē", "っへえ", "ッヘー"],
  ["hhī", "っひい", "ッヒー"],
  ["hhō", "っほう", "ッホー"],
  ["hhū", "っふう", "ッフー"],
  ["hi", "ひ", "ヒ"],
  ["hii", "ひい", "ヒー"],
  ["ho", "ほ", "ホ"],
  ["hoo", "ほお", "ホー"],
  ["hou", "ほう", "ホー"],
  ["hu", "ふ", "フ"],
  ["huu", "ふう", "フー"],
  ["hya", "ひゃ", "ヒャ"],
  ["hyaa", "ひゃあ", "ヒャー"],
  ["hye", "ひぇ", "ヒェ"],
  ["hyee", "ひぇえ", "ヒェー"],
  ["hyi", "ひぃ", "ヒィ"],
  ["hyii", "ひぃい", "ヒィー"],
  ["hyo", "ひょ", "ヒョ"],
  ["hyoo", "ひょお", "ヒョー"],
  ["hyou", "ひょう", "ヒョー"],
  ["hyu", "ひゅ", "ヒュ"],
  ["hyuu", "ひゅう", "ヒュー"],
  ["hyâ", "ひゃあ", "ヒャー"],
  ["hyê", "ひぇえ", "ヒェー"],
  ["hyî", "ひぃい", "ヒィー"],
  ["hyô", "ひょう", "ヒョー"],
  ["hyû", "ひゅう", "ヒュー"],
  ["hyā", "ひゃあ", "ヒャー"],
  ["hyē", "ひぇえ", "ヒェー"],
  ["hyī", "ひぃい", "ヒィー"],
  ["hyō", "ひょう", "ヒョー"],
  ["hyū", "ひゅう", "ヒュー"],
  ["hâ", "はあ", "ハー"],
  ["hê", "へえ", "ヘー"],
  ["hî", "ひい", "ヒー"],
  ["hô", "ほう", "ホー"],
  ["hû", "ふう", "フー"],
  ["hā", "はあ", "ハー"],
  ["hē", "へえ", "ヘー"],
  ["hī", "ひい", "ヒー"],
  ["hō", "ほう", "ホー"],
  ["hū", "ふう", "フー"],
  ["i", "い", "イ"],
  ["ii", "いい", "イイ"],
  ["j", "じ", "ジ"],
  ["ja", "じゃ", "ジャ"],
  ["jaa", "じゃあ", "ジャー"],
  ["je", "じぇ", "ジェ"],
  ["jee", "じぇえ", "ジェー"],
  ["ji", "じ", "ジ"],
  ["jii", "じい", "ジー"],
  ["jj", "っじ", "ッジ"],
  ["jja", "っじゃ", "ッジャ"],
  ["jjaa", "っじゃあ", "ッジャー"],
  ["jje", "っじぇ", "ッジェ"],
  ["jjee", "っじぇえ", "ッジェー"],
  ["jji", "っじ", "ッジ"],
  ["jjii", "っじい", "ッジー"],
  ["jjo", "っじょ", "ッジョ"],
  ["jjoo", "っじょお", "ッジョー"],
  ["jjou", "っじょう", "ッジョー"],
  ["jju", "っじゅ", "ッジュ"],
  ["jjuu", "っじゅう", "ッジュー"],
  ["jjya", "っじゃ", "ッジャ"],
  ["jjyaa", "っじゃあ", "ッジャー"],
  ["jjye", "っじぇ", "ッジェ"],
  ["jjyee", "っじぇえ", "ッジェー"],
  ["jjyi", "っじぃ", "ッジィ"],
  ["jjyii", "っじぃい", "ッジィー"],
  ["jjyo", "っじょ", "ッジョ"],
  ["jjyoo", "っじょお", "ッジョー"],
  ["jjyou", "っじょう", "ッジョー"],
  ["jjyu", "っじゅ", "ッジュ"],
  ["jjyuu", "っじゅう", "ッジュー"],
  ["jjyâ", "っじゃあ", "ッジャー"],
  ["jjyê", "っじぇえ", "ッジェー"],
  ["jjyî", "っじぃい", "ッジィー"],
  ["jjyô", "っじょう", "ッジョー"],
  ["jjyû", "っじゅう", "ッジュー"],
  ["jjyā", "っじゃあ", "ッジャー"],
  ["jjyē", "っじぇえ", "ッジェー"],
  ["jjyī", "っじぃい", "ッジィー"],
  ["jjyō", "っじょう", "ッジョー"],
  ["jjyū", "っじゅう", "ッジュー"],
  ["jjâ", "っじゃあ", "ッジャー"],
  ["jjê", "っじぇえ", "ッジェー"],
  ["jjî", "っじい", "ッジー"],
  ["jjô", "っじょう", "ッジョー"],
  ["jjû", "っじゅう", "ッジュー"],
  ["jjā", "っじゃあ", "ッジャー"],
  ["jjē", "っじぇえ", "ッジェー"],
  ["jjī", "っじい", "ッジー"],
  ["jjō", "っじょう", "ッジョー"],
  ["jjū", "っじゅう", "ッジュー"],
  ["jo", "じょ", "ジョ"],
  ["joo", "じょお", "ジョー"],
  ["jou", "じょう", "ジョー"],
  ["ju", "じゅ", "ジュ"],
  ["juu", "じゅう", "ジュー"],
  ["jya", "じゃ", "ジャ"],
  ["jyaa", "じゃあ", "ジャー"],
  ["jye", "じぇ", "ジェ"],
  ["jyee", "じぇえ", "ジェー"],
  ["jyi", "じぃ", "ジィ"],
  ["jyii", "じぃい", "ジィー"],
  ["jyo", "じょ", "ジョ"],
  ["jyoo", "じょお", "ジョー"],
  ["jyou", "じょう", "ジョー"],
  ["jyu", "じゅ", "ジュ"],
  ["jyuu", "じゅう", "ジュー"],
  ["jyâ", "じゃあ", "ジャー"],
  ["jyê", "じぇえ", "ジェー"],
  ["jyî", "じぃい", "ジィー"],
  ["jyô", "じょう", "ジョー"],
  ["jyû", "じゅう", "ジュー"],
  ["jyā", "じゃあ", "ジャー"],
  ["jyē", "じぇえ", "ジェー"],
  ["jyī", "じぃい", "ジィー"],
  ["jyō", "じょう", "ジョー"],
  ["jyū", "じゅう", "ジュー"],
  ["jâ", "じゃあ", "ジャー"],
  ["jê", "じぇえ", "ジェー"],
  ["jî", "じい", "ジー"],
  ["jô", "じょう", "ジョー"],
  ["jû", "じゅう", "ジュー"],
  ["jā", "じゃあ", "ジャー"],
  ["jē", "じぇえ", "ジェー"],
  ["jī", "じい", "ジー"],
  ["jō", "じょう", "ジョー"],
  ["jū", "じゅう", "ジュー"],
  ["k", "く", "ク"],
  ["ka", "か", "カ"],
  ["kaa", "かあ", "カー"],
  ["ke", "け", "ケ"],
  ["kee", "けえ", "ケー"],
  ["ki", "き", "キ"],
  ["kii", "きい", "キー"],
  ["kk", "っく", "ック"],
  ["kka", "っか", "ッカ"],
  ["kkaa", "っかあ", "ッカー"],
  ["kke", "っけ", "ッケ"],
  ["kkee", "っけえ", "ッケー"],
  ["kki", "っき", "ッキ"],
  ["kkii", "っきい", "ッキー"],
  ["kko", "っこ", "ッコ"],
  ["kkoo", "っこお", "ッコー"],
  ["kkou", "っこう", "ッコー"],
  ["kku", "っく", "ック"],
  ["kkuu", "っくう", "ックー"],
  ["kkwa", "っくぁ", "ックァ"],
  ["kkwaa", "っくぁあ", "ックァー"],
  ["kkwe", "っくぇ", "ックェ"],
  ["kkwee", "っくぇえ", "ックェー"],
  ["kkwi", "っくぃ", "ックィ"],
  ["kkwii", "っくぃい", "ックィー"],
  ["kkwo", "っくぉ", "ックォ"],
  ["kkwoo", "っくぉお", "ックォー"],
  ["kkwou", "っくぉう", "ックォー"],
  ["kkwu", "っくぅ", "ックゥ"],
  ["kkwuu", "っくぅう", "ックゥー"],
  ["kkwâ", "っくぁあ", "ックァー"],
  ["kkwê", "っくぇえ", "ックェー"],
  ["kkwî", "っくぃい", "ックィー"],
  ["kkwô", "っくぉう", "ックォー"],
  ["kkwû", "っくぅう", "ックゥー"],
  ["kkwā", "っくぁあ", "ックァー"],
  ["kkwē", "っくぇえ", "ックェー"],
  ["kkwī", "っくぃい", "ックィー"],
  ["kkwō", "っくぉう", "ックォー"],
  ["kkwū", "っくぅう", "ックゥー"],
  ["kkya", "っきゃ", "ッキャ"],
  ["kkyaa", "っきゃあ", "ッキャー"],
  ["kkye", "っきぇ", "ッキェ"],
  ["kkyee", "っきぇえ", "ッキェー"],
  ["kkyi", "っきぃ", "ッキィ"],
  ["kkyii", "っきぃい", "ッキィー"],
  ["kkyo", "っきょ", "ッキョ"],
  ["kkyoo", "っきょお", "ッキョー"],
  ["kkyou", "っきょう", "ッキョー"],
  ["kkyu", "っきゅ", "ッキュ"],
  ["kkyuu", "っきゅう", "ッキュー"],
  ["kkyâ", "っきゃあ", "ッキャー"],
  ["kkyê", "っきぇえ", "ッキェー"],
  ["kkyî", "っきぃい", "ッキィー"],
  ["kkyô", "っきょう", "ッキョー"],
  ["kkyû", "っきゅう", "ッキュー"],
  ["kkyā", "っきゃあ", "ッキャー"],
  ["kkyē", "っきぇえ", "ッキェー"],
  ["kkyī", "っきぃい", "ッキィー"],
  ["kkyō", "っきょう", "ッキョー"],
  ["kkyū", "っきゅう", "ッキュー"],
  ["kkâ", "っかあ", "ッカー"],
  ["kkê", "っけえ", "ッケー"],
  ["kkî", "っきい", "ッキー"],
  ["kkô", "っこう", "ッコー"],
  ["kkû", "っくう", "ックー"],
  ["kkā", "っかあ", "ッカー"],
  ["kkē", "っけえ", "ッケー"],
  ["kkī", "っきい", "ッキー"],
  ["kkō", "っこう", "ッコー"],
  ["kkū", "っくう", "ックー"],
  ["ko", "こ", "コ"],
  ["koo", "こお", "コー"],
  ["kou", "こう", "コー"],
  ["kqu", "っくぅ", "ックゥ"],
  ["kqua", "っくぁ", "ックァ"],
  ["kquaa", "っくぁあ", "ックァー"],
  ["kque", "っくぇ", "ックェ"],
  ["kquee", "っくぇえ", "ックェー"],
  ["kqui", "っくぃ", "ックィ"],
  ["kquii", "っくぃい", "ックィー"],
  ["kquo", "っくぉ", "ックォ"],
  ["kquoo", "っくぉお", "ックォー"],
  ["kquou", "っくぉう", "ックォー"],
  ["kquu", "っくぅう", "ックゥー"],
  ["kquâ", "っくぁあ", "ックァー"],
  ["kquê", "っくぇえ", "ックェー"],
  ["kquî", "っくぃい", "ックィー"],
  ["kquô", "っくぉう", "ックォー"],
  ["kquā", "っくぁあ", "ックァー"],
  ["kquē", "っくぇえ", "ックェー"],
  ["kquī", "っくぃい", "ックィー"],
  ["kquō", "っくぉう", "ックォー"],
  ["kqû", "っくぅう", "ックゥー"],
  ["kqū", "っくぅう", "ックゥー"],
  ["ku", "く", "ク"],
  ["kuu", "くう", "クー"],
  ["kwa", "くぁ", "クァ"],
  ["kwaa", "くぁあ", "クァー"],
  ["kwe", "くぇ", "クェ"],
  ["kwee", "くぇえ", "クェー"],
  ["kwi", "くぃ", "クィ"],
  ["kwii", "くぃい", "クィー"],
  ["kwo", "くぉ", "クォ"],
  ["kwoo", "くぉお", "クォー"],
  ["kwou", "くぉう", "クォー"],
  ["kwu", "くぅ", "クゥ"],
  ["kwuu", "くぅう", "クゥー"],
  ["kwâ", "くぁあ", "クァー"],
  ["kwê", "くぇえ", "クェー"],
  ["kwî", "くぃい", "クィー"],
  ["kwô", "くぉう", "クォー"],
  ["kwû", "くぅう", "クゥー"],
  ["kwā", "くぁあ", "クァー"],
  ["kwē", "くぇえ", "クェー"],
  ["kwī", "くぃい", "クィー"],
  ["kwō", "くぉう", "クォー"],
  ["kwū", "くぅう", "クゥー"],
  ["kya", "きゃ", "キャ"],
  ["kyaa", "きゃあ", "キャー"],
  ["kye", "きぇ", "キェ"],
  ["kyee", "きぇえ", "キェー"],
  ["kyi", "きぃ", "キィ"],
  ["kyii", "きぃい", "キィー"],
  ["kyo", "きょ", "キョ"],
  ["kyoo", "きょお", "キョー"],
  ["kyou", "きょう", "キョー"],
  ["kyu", "きゅ", "キュ"],
  ["kyuu", "きゅう", "キュー"],
  ["kyâ", "きゃあ", "キャー"],
  ["kyê", "きぇえ", "キェー"],
  ["kyî", "きぃい", "キィー"],
  ["kyô", "きょう", "キョー"],
  ["kyû", "きゅう", "キュー"],
  ["kyā", "きゃあ", "キャー"],
  ["kyē", "きぇえ", "キェー"],
  ["kyī", "きぃい", "キィー"],
  ["kyō", "きょう", "キョー"],
  ["kyū", "きゅう", "キュー"],
  ["kâ", "かあ", "カー"],
  ["kê", "けえ", "ケー"],
  ["kî", "きい", "キー"],
  ["kô", "こう", "コー"],
  ["kû", "くう", "クー"],
  ["kā", "かあ", "カー"],
  ["kē", "けえ", "ケー"],
  ["kī", "きい", "キー"],
  ["kō", "こう", "コー"],
  ["kū", "くう", "クー"],
  ["l", "る", "ル"],
  ["la", "ら", "ラ"],
  ["laa", "らあ", "ラー"],
  ["le", "れ", "レ"],
  ["lee", "れえ", "レー"],
  ["li", "り", "リ"],
  ["lii", "りい", "リー"],
  ["ll", "っる", "ッル"],
  ["lla", "っら", "ッラ"],
  ["llaa", "っらあ", "ッラー"],
  ["lle", "っれ", "ッレ"],
  ["llee", "っれえ", "ッレー"],
  ["lli", "っり", "ッリ"],
  ["llii", "っりい", "ッリー"],
  ["llo", "っろ", "ッロ"],
  ["lloo", "っろお", "ッロー"],
  ["llou", "っろう", "ッロー"],
  ["llu", "っる", "ッル"],
  ["lluu", "っるう", "ッルー"],
  ["llya", "っりゃ", "ッラヤ"],
  ["llyaa", "っりゃあ", "ッラヤー"],
  ["llye", "っりぇ", "ッリェ"],
  ["llyee", "っりぇえ", "ッリェー"],
  ["llyi", "っりぃ", "ッリィ"],
  ["llyii", "っりぃい", "ッリィー"],
  ["llyo", "っりょ", "ッリョ"],
  ["llyoo", "っりょお", "ッリョー"],
  ["llyou", "っりょう", "ッリョー"],
  ["llyu", "っりゅ", "ッリュ"],
  ["llyuu", "っりゅう", "ッリュー"],
  ["llyâ", "っりゃあ", "ッラヤー"],
  ["llyê", "っりぇえ", "ッリェー"],
  ["llyî", "っりぃい", "ッリィー"],
  ["llyô", "っりょう", "ッリョー"],
  ["llyû", "っりゅう", "ッリュー"],
  ["llyā", "っりゃあ", "ッラヤー"],
  ["llyē", "っりぇえ", "ッリェー"],
  ["llyī", "っりぃい", "ッリィー"],
  ["llyō", "っりょう", "ッリョー"],
  ["llyū", "っりゅう", "ッリュー"],
  ["llâ", "っらあ", "ッラー"],
  ["llê", "っれえ", "ッレー"],
  ["llî", "っりい", "ッリー"],
  ["llô", "っろう", "ッロー"],
  ["llû", "っるう", "ッルー"],
  ["llā", "っらあ", "ッラー"],
  ["llē", "っれえ", "ッレー"],
  ["llī", "っりい", "ッリー"],
  ["llō", "っろう", "ッロー"],
  ["llū", "っるう", "ッルー"],
  ["lo", "ろ", "ロ"],
  ["loo", "ろお", "ロー"],
  ["lou", "ろう", "ロー"],
  ["lu", "る", "ル"],
  ["luu", "るう", "ルー"],
  ["lya", "りゃ", "ラヤ"],
  ["lyaa", "りゃあ", "ラヤー"],
  ["lye", "りぇ", "リェ"],
  ["lyee", "りぇえ", "リェー"],
  ["lyi", "りぃ", "リィ"],
  ["lyii", "りぃい", "リィー"],
  ["lyo", "りょ", "リョ"],
  ["lyoo", "りょお", "リョー"],
  ["lyou", "りょう", "リョー"],
  ["lyu", "りゅ", "リュ"],
  ["lyuu", "りゅう", "リュー"],
  ["lyâ", "りゃあ", "ラヤー"],
  ["lyê", "りぇえ", "リェー"],
  ["lyî", "りぃい", "リィー"],
  ["lyô", "りょう", "リョー"],
  ["lyû", "りゅう", "リュー"],
  ["lyā", "りゃあ", "ラヤー"],
  ["lyē", "りぇえ", "リェー"],
  ["lyī", "りぃい", "リィー"],
  ["lyō", "りょう", "リョー"],
  ["lyū", "りゅう", "リュー"],
  ["lâ", "らあ", "ラー"],
  ["lê", "れえ", "レー"],
  ["lî", "りい", "リー"],
  ["lô", "ろう", "ロー"],
  ["lû", "るう", "ルー"],
  ["lā", "らあ", "ラー"],
  ["lē", "れえ", "レー"],
  ["lī", "りい", "リー"],
  ["lō", "ろう", "ロー"],
  ["lū", "るう", "ルー"],
  ["m", "む", "ム"],
  ["ma", "ま", "マ"],
  ["maa", "まあ", "マー"],
  ["mb", "んぶ", "ンブ"],
  ["mba", "んば", "ンバ"],
  ["mbe", "んべ", "ンベ"],
  ["mbee", "んべえ", "ンベー"],
  ["mbi", "んび", "ンビ"],
  ["mbii", "んびい", "ンビー"],
  ["mbo", "んぼ", "ンボ"],
  ["mboo", "んぼお", "ンボー"],
  ["mbou", "んぼう", "ンボー"],
  ["mbu", "んぶ", "ンブ"],
  ["mbuu", "んぶう", "ンブー"],
  ["mbya", "んびゃ", "ンビャ"],
  ["mbyaa", "んびゃあ", "ンビャー"],
  ["mbye", "んびぇ", "ンビェ"],
  ["mbyee", "んびぇえ", "ンビェー"],
  ["mbyi", "んびぃ", "ンビィ"],
  ["mbyii", "んびぃい", "ンビィー"],
  ["mbyo", "んびょ", "ンビョ"],
  ["mbyoo", "んびょお", "ンビョー"],
  ["mbyou", "んびょう", "ンビョー"],
  ["mbyu", "んびゅ", "ンビュ"],
  ["mbyuu", "んびゅう", "ンビュー"],
  ["mbyâ", "んびゃあ", "ンビャー"],
  ["mbyê", "んびぇえ", "ンビェー"],
  ["mbyî", "んびぃい", "ンビィー"],
  ["mbyô", "んびょう", "ンビョー"],
  ["mbyû", "んびゅう", "ンビュー"],
  ["mbyā", "んびゃあ", "ンビャー"],
  ["mbyē", "んびぇえ", "ンビェー"],
  ["mbyī", "んびぃい", "ンビィー"],
  ["mbyō", "んびょう", "ンビョー"],
  ["mbyū", "んびゅう", "ンビュー"],
  ["mbâ", "んばあ", "ンバー"],
  ["mbê", "んべえ", "ンベー"],
  ["mbî", "んびい", "ンビー"],
  ["mbô", "んぼう", "ンボー"],
  ["mbû", "んぶう", "ンブー"],
  ["mbā", "んばあ", "ンバー"],
  ["mbē", "んべえ", "ンベー"],
  ["mbī", "んびい", "ンビー"],
  ["mbō", "んぼう", "ンボー"],
  ["mbū", "んぶう", "ンブー"],
  ["me", "め", "メ"],
  ["mee", "めえ", "メー"],
  ["mi", "み", "ミ"],
  ["mii", "みい", "ミー"],
  ["mm", "んむ", "ンム"],
  ["mma", "んま", "ンマ"],
  ["mmaa", "んまあ", "ンマー"],
  ["mme", "んめ", "ンメ"],
  ["mmee", "んめえ", "ンメー"],
  ["mmi", "んみ", "ンミ"],
  ["mmii", "んみい", "ンミー"],
  ["mmo", "んも", "ンモ"],
  ["mmoo", "んもお", "ンモー"],
  ["mmou", "んもう", "ンモー"],
  ["mmu", "んむ", "ンム"],
  ["mmuu", "んむう", "ンムー"],
  ["mmya", "んみゃ", "ンミャ"],
  ["mmyaa", "んみゃあ", "ンミャー"],
  ["mmye", "んみぇ", "ンミェ"],
  ["mmyee", "んみぇえ", "ンミェー"],
  ["mmyi", "んみぃ", "ンミィ"],
  ["mmyii", "んみぃい", "ンミィー"],
  ["mmyo", "んみょ", "ンミョ"],
  ["mmyoo", "んみょお", "ンミョー"],
  ["mmyou", "んみょう", "ンミョー"],
  ["mmyu", "んみゅ", "ンミュ"],
  ["mmyuu", "んみゅう", "ンミュー"],
  ["mmyâ", "んみゃあ", "ンミャー"],
  ["mmyê", "んみぇえ", "ンミェー"],
  ["mmyî", "んみぃい", "ンミィー"],
  ["mmyô", "んみょう", "ンミョー"],
  ["mmyû", "んみゅう", "ンミュー"],
  ["mmyā", "んみゃあ", "ンミャー"],
  ["mmyē", "んみぇえ", "ンミェー"],
  ["mmyī", "んみぃい", "ンミィー"],
  ["mmyō", "んみょう", "ンミョー"],
  ["mmyū", "んみゅう", "ンミュー"],
  ["mmâ", "んまあ", "ンマー"],
  ["mmê", "んめえ", "ンメー"],
  ["mmî", "んみい", "ンミー"],
  ["mmô", "んもう", "ンモー"],
  ["mmû", "んむう", "ンムー"],
  ["mmā", "んまあ", "ンマー"],
  ["mmē", "んめえ", "ンメー"],
  ["mmī", "んみい", "ンミー"],
  ["mmō", "んもう", "ンモー"],
  ["mmū", "んむう", "ンムー"],
  ["mo", "も", "モ"],
  ["moo", "もお", "モー"],
  ["mou", "もう", "モー"],
  ["mp", "んぷ", "ンプ"],
  ["mpa", "んぱ", "ンパ"],
  ["mpaa", "んぱあ", "ンパー"],
  ["mpe", "んぺ", "ンペ"],
  ["mpee", "んぺえ", "ンペー"],
  ["mpi", "んぴ", "ンピ"],
  ["mpii", "んぴい", "ンピー"],
  ["mpo", "んぽ", "ンポ"],
  ["mpoo", "んぽお", "ンポー"],
  ["mpou", "んぽう", "ンポー"],
  ["mpu", "んぷ", "ンプ"],
  ["mpuu", "んぷう", "ンプー"],
  ["mpya", "んぴゃ", "ンピャ"],
  ["mpyaa", "んぴゃあ", "ンピャー"],
  ["mpye", "んぴぇ", "ンピェ"],
  ["mpyee", "んぴぇえ", "ンピェー"],
  ["mpyi", "んぴぃ", "ンピィ"],
  ["mpyii", "んぴぃい", "ンピィー"],
  ["mpyo", "んぴょ", "ンピョ"],
  ["mpyoo", "んぴょお", "ンピョー"],
  ["mpyou", "んぴょう", "ンピョー"],
  ["mpyu", "んぴゅ", "ンピュ"],
  ["mpyuu", "んぴゅう", "ンピュー"],
  ["mpyâ", "んぴゃあ", "ンピャー"],
  ["mpyê", "んぴぇえ", "ンピェー"],
  ["mpyî", "んぴぃい", "ンピィー"],
  ["mpyô", "んぴょう", "ンピョー"],
  ["mpyû", "んぴゅう", "ンピュー"],
  ["mpyā", "んぴゃあ", "ンピャー"],
  ["mpyē", "んぴぇえ", "ンピェー"],
  ["mpyī", "んぴぃい", "ンピィー"],
  ["mpyō", "んぴょう", "ンピョー"],
  ["mpyū", "んぴゅう", "ンピュー"],
  ["mpâ", "んぱあ", "ンパー"],
  ["mpê", "んぺえ", "ンペー"],
  ["mpî", "んぴい", "ンピー"],
  ["mpô", "んぽう", "ンポー"],
  ["mpû", "んぷう", "ンプー"],
  ["mpā", "んぱあ", "ンパー"],
  ["mpē", "んぺえ", "ンペー"],
  ["mpī", "んぴい", "ンピー"],
  ["mpō", "んぽう", "ンポー"],
  ["mpū", "んぷう", "ンプー"],
  ["mu", "む", "ム"],
  ["muu", "むう", "ムー"],
  ["mya", "みゃ", "ミャ"],
  ["myaa", "みゃあ", "ミャー"],
  ["mye", "みぇ", "ミェ"],
  ["myee", "みぇえ", "ミェー"],
  ["myi", "みぃ", "ミィ"],
  ["myii", "みぃい", "ミィー"],
  ["myo", "みょ", "ミョ"],
  ["myoo", "みょお", "ミョー"],
  ["myou", "みょう", "ミョー"],
  ["myu", "みゅ", "ミュ"],
  ["myuu", "みゅう", "ミュー"],
  ["myâ", "みゃあ", "ミャー"],
  ["myê", "みぇえ", "ミェー"],
  ["myî", "みぃい", "ミィー"],
  ["myô", "みょう", "ミョー"],
  ["myû", "みゅう", "ミュー"],
  ["myā", "みゃあ", "ミャー"],
  ["myē", "みぇえ", "ミェー"],
  ["myī", "みぃい", "ミィー"],
  ["myō", "みょう", "ミョー"],
  ["myū", "みゅう", "ミュー"],
  ["mâ", "まあ", "マー"],
  ["mê", "めえ", "メー"],
  ["mî", "みい", "ミー"],
  ["mô", "もう", "モー"],
  ["mû", "むう", "ムー"],
  ["mā", "まあ", "マー"],
  ["mē", "めえ", "メー"],
  ["mī", "みい", "ミー"],
  ["mō", "もう", "モー"],
  ["mū", "むう", "ムー"],
  ["n", "ん", "ン"],
  ["n'", "ん", "ン"],
  ["na", "な", "ナ"],
  ["naa", "なあ", "ナー"],
  ["ne", "ね", "ネ"],
  ["nee", "ねえ", "ネー"],
  ["ni", "に", "ニ"],
  ["nii", "にい", "ニー"],
  ["no", "の", "ノ"],
  ["noo", "のお", "ノー"],
  ["nou", "のう", "ノー"],
  ["nu", "ぬ", "ヌ"],
  ["nuu", "ぬう", "ヌー"],
  ["nya", "にゃ", "ニャ"],
  ["nyaa", "にゃあ", "ニャー"],
  ["nye", "にぇ", "ニェ"],
  ["nyee", "にぇえ", "ニェー"],
  ["nyi", "にぃ", "ニィ"],
  ["nyii", "にぃい", "ニィー"],
  ["nyo", "にょ", "ニョ"],
  ["nyoo", "にょお", "ニョー"],
  ["nyou", "にょう", "ニョー"],
  ["nyu", "にゅ", "ニュ"],
  ["nyuu", "にゅう", "ニュー"],
  ["nyâ", "にゃあ", "ニャー"],
  ["nyê", "にぇえ", "ニェー"],
  ["nyî", "にぃい", "ニィー"],
  ["nyô", "にょう", "ニョー"],
  ["nyû", "にゅう", "ニュー"],
  ["nyā", "にゃあ", "ニャー"],
  ["nyē", "にぇえ", "ニェー"],
  ["nyī", "にぃい", "ニィー"],
  ["nyō", "にょう", "ニョー"],
  ["nyū", "にゅう", "ニュー"],
  ["nâ", "なあ", "ナー"],
  ["nê", "ねえ", "ネー"],
  ["nî", "にい", "ニー"],
  ["nô", "のう", "ノー"],
  ["nû", "ぬう", "ヌー"],
  ["nā", "なあ", "ナー"],
  ["nē", "ねえ", "ネー"],
  ["nī", "にい", "ニー"],
  ["nō", "のう", "ノー"],
  ["nū", "ぬう", "ヌー"],
  ["o", "お", "オ"],
  ["oo", "おお", "オー"],
  ["ou", "おう", "オー"],
  ["p", "ぷ", "プ"],
  ["pa", "ぱ", "パ"],
  ["paa", "ぱあ", "パー"],
  ["pe", "ぺ", "ペ"],
  ["pee", "ぺえ", "ペー"],
  ["pi", "ぴ", "ピ"],
  ["pii", "ぴい", "ピー"],
  ["po", "ぽ", "ポ"],
  ["poo", "ぽお", "ポー"],
  ["pou", "ぽう", "ポー"],
  ["pp", "っぷ", "ップ"],
  ["ppa", "っぱ", "ッパ"],
  ["ppaa", "っぱあ", "ッパー"],
  ["ppe", "っぺ", "ッペ"],
  ["ppee", "っぺえ", "ッペー"],
  ["ppi", "っぴ", "ッピ"],
  ["ppii", "っぴい", "ッピー"],
  ["ppo", "っぽ", "ッポ"],
  ["ppoo", "っぽお", "ッポー"],
  ["ppou", "っぽう", "ッポー"],
  ["ppu", "っぷ", "ップ"],
  ["ppuu", "っぷう", "ップー"],
  ["ppya", "っぴゃ", "ッピャ"],
  ["ppyaa", "っぴゃあ", "ッピャー"],
  ["ppye", "っぴぇ", "ッピェ"],
  ["ppyee", "っぴぇえ", "ッピェー"],
  ["ppyi", "っぴぃ", "ッピィ"],
  ["ppyii", "っぴぃい", "ッピィー"],
  ["ppyo", "っぴょ", "ッピョ"],
  ["ppyoo", "っぴょお", "ッピョー"],
  ["ppyou", "っぴょう", "ッピョー"],
  ["ppyu", "っぴゅ", "ッピュ"],
  ["ppyuu", "っぴゅう", "ッピュー"],
  ["ppyâ", "っぴゃあ", "ッピャー"],
  ["ppyê", "っぴぇえ", "ッピェー"],
  ["ppyî", "っぴぃい", "ッピィー"],
  ["ppyô", "っぴょう", "ッピョー"],
  ["ppyû", "っぴゅう", "ッピュー"],
  ["ppyā", "っぴゃあ", "ッピャー"],
  ["ppyē", "っぴぇえ", "ッピェー"],
  ["ppyī", "っぴぃい", "ッピィー"],
  ["ppyō", "っぴょう", "ッピョー"],
  ["ppyū", "っぴゅう", "ッピュー"],
  ["ppâ", "っぱあ", "ッパー"],
  ["ppê", "っぺえ", "ッペー"],
  ["ppî", "っぴい", "ッピー"],
  ["ppô", "っぽう", "ッポー"],
  ["ppû", "っぷう", "ップー"],
  ["ppā", "っぱあ", "ッパー"],
  ["ppē", "っぺえ", "ッペー"],
  ["ppī", "っぴい", "ッピー"],
  ["ppō", "っぽう", "ッポー"],
  ["ppū", "っぷう", "ップー"],
  ["pu", "ぷ", "プ"],
  ["puu", "ぷう", "プー"],
  ["pya", "ぴゃ", "ピャ"],
  ["pyaa", "ぴゃあ", "ピャー"],
  ["pye", "ぴぇ", "ピェ"],
  ["pyee", "ぴぇえ", "ピェー"],
  ["pyi", "ぴぃ", "ピィ"],
  ["pyii", "ぴぃい", "ピィー"],
  ["pyo", "ぴょ", "ピョ"],
  ["pyoo", "ぴょお", "ピョー"],
  ["pyou", "ぴょう", "ピョー"],
  ["pyu", "ぴゅ", "ピュ"],
  ["pyuu", "ぴゅう", "ピュー"],
  ["pyâ", "ぴゃあ", "ピャー"],
  ["pyê", "ぴぇえ", "ピェー"],
  ["pyî", "ぴぃい", "ピィー"],
  ["pyô", "ぴょう", "ピョー"],
  ["pyû", "ぴゅう", "ピュー"],
  ["pyā", "ぴゃあ", "ピャー"],
  ["pyē", "ぴぇえ", "ピェー"],
  ["pyī", "ぴぃい", "ピィー"],
  ["pyō", "ぴょう", "ピョー"],
  ["pyū", "ぴゅう", "ピュー"],
  ["pâ", "ぱあ", "パー"],
  ["pê", "ぺえ", "ペー"],
  ["pî", "ぴい", "ピー"],
  ["pô", "ぽう", "ポー"],
  ["pû", "ぷう", "プー"],
  ["pā", "ぱあ", "パー"],
  ["pē", "ぺえ", "ペー"],
  ["pī", "ぴい", "ピー"],
  ["pō", "ぽう", "ポー"],
  ["pū", "ぷう", "プー"],
  ["q", "く", "ク"],
  ["qqu", "っくぅ", "ックゥ"],
  ["qqua", "っくぁ", "ックァ"],
  ["qquaa", "っくぁあ", "ックァー"],
  ["qque", "っくぇ", "ックェ"],
  ["qquee", "っくぇえ", "ックェー"],
  ["qqui", "っくぃ", "ックィ"],
  ["qquii", "っくぃい", "ックィー"],
  ["qquo", "っくぉ", "ックォ"],
  ["qquoo", "っくぉお", "ックォー"],
  ["qquou", "っくぉう", "ックォー"],
  ["qquu", "っくぅう", "ックゥー"],
  ["qquâ", "っくぁあ", "ックァー"],
  ["qquê", "っくぇえ", "ックェー"],
  ["qquî", "っくぃい", "ックィー"],
  ["qquô", "っくぉう", "ックォー"],
  ["qquā", "っくぁあ", "ックァー"],
  ["qquē", "っくぇえ", "ックェー"],
  ["qquī", "っくぃい", "ックィー"],
  ["qquō", "っくぉう", "ックォー"],
  ["qqû", "っくぅう", "ックゥー"],
  ["qqū", "っくぅう", "ックゥー"],
  ["qu", "くぅ", "クゥ"],
  ["qua", "くぁ", "クァ"],
  ["quaa", "くぁあ", "クァー"],
  ["que", "くぇ", "クェ"],
  ["quee", "くぇえ", "クェー"],
  ["qui", "くぃ", "クィ"],
  ["quii", "くぃい", "クィー"],
  ["quo", "くぉ", "クォ"],
  ["quoo", "くぉお", "クォー"],
  ["quou", "くぉう", "クォー"],
  ["quu", "くぅう", "クゥー"],
  ["quâ", "くぁあ", "クァー"],
  ["quê", "くぇえ", "クェー"],
  ["quî", "くぃい", "クィー"],
  ["quô", "くぉう", "クォー"],
  ["quā", "くぁあ", "クァー"],
  ["quē", "くぇえ", "クェー"],
  ["quī", "くぃい", "クィー"],
  ["quō", "くぉう", "クォー"],
  ["qû", "くぅう", "クゥー"],
  ["qū", "くぅう", "クゥー"],
  ["r", "る", "ル"],
  ["ra", "ら", "ラ"],
  ["raa", "らあ", "ラー"],
  ["re", "れ", "レ"],
  ["ree", "れえ", "レー"],
  ["ri", "り", "リ"],
  ["rii", "りい", "リー"],
  ["rl", "っる", "ッル"],
  ["rla", "っら", "ッラ"],
  ["rlaa", "っらあ", "ッラー"],
  ["rle", "っれ", "ッレ"],
  ["rlee", "っれえ", "ッレー"],
  ["rli", "っり", "ッリ"],
  ["rlii", "っりい", "ッリー"],
  ["rlo", "っろ", "ッロ"],
  ["rloo", "っろお", "ッロー"],
  ["rlou", "っろう", "ッロー"],
  ["rlu", "っる", "ッル"],
  ["rluu", "っるう", "ッルー"],
  ["rlya", "っりゃ", "ッリャ"],
  ["rlyaa", "っりゃあ", "ッリャー"],
  ["rlye", "っりぇ", "ッリェ"],
  ["rlyee", "っりぇえ", "ッリェー"],
  ["rlyi", "っりぃ", "ッリィ"],
  ["rlyii", "っりぃい", "ッリィー"],
  ["rlyo", "っりょ", "ッリョ"],
  ["rlyoo", "っりょお", "ッリョー"],
  ["rlyou", "っりょう", "ッリョー"],
  ["rlyu", "っりゅ", "ッリュ"],
  ["rlyuu", "っりゅう", "ッリュー"],
  ["rlyâ", "っりゃあ", "ッリャー"],
  ["rlyê", "っりぇえ", "ッリェー"],
  ["rlyî", "っりぃい", "ッリィー"],
  ["rlyô", "っりょう", "ッリョー"],
  ["rlyû", "っりゅう", "ッリュー"],
  ["rlyā", "っりゃあ", "ッリャー"],
  ["rlyē", "っりぇえ", "ッリェー"],
  ["rlyī", "っりぃい", "ッリィー"],
  ["rlyō", "っりょう", "ッリョー"],
  ["rlyū", "っりゅう", "ッリュー"],
  ["rlâ", "っらあ", "ッラー"],
  ["rlê", "っれえ", "ッレー"],
  ["rlî", "っりい", "ッリー"],
  ["rlô", "っろう", "ッロー"],
  ["rlû", "っるう", "ッルー"],
  ["rlā", "っらあ", "ッラー"],
  ["rlē", "っれえ", "ッレー"],
  ["rlī", "っりい", "ッリー"],
  ["rlō", "っろう", "ッロー"],
  ["rlū", "っるう", "ッルー"],
  ["ro", "ろ", "ロ"],
  ["roo", "ろお", "ロー"],
  ["rou", "ろう", "ロー"],
  ["rr", "っる", "ッル"],
  ["rra", "っら", "ッラ"],
  ["rraa", "っらあ", "ッラー"],
  ["rre", "っれ", "ッレ"],
  ["rree", "っれえ", "ッレー"],
  ["rri", "っり", "ッリ"],
  ["rrii", "っりい", "ッリー"],
  ["rro", "っろ", "ッロ"],
  ["rroo", "っろお", "ッロー"],
  ["rrou", "っろう", "ッロー"],
  ["rru", "っる", "ッル"],
  ["rruu", "っるう", "ッルー"],
  ["rrya", "っりゃ", "ッリャ"],
  ["rryaa", "っりゃあ", "ッリャー"],
  ["rrye", "っりぇ", "ッリェ"],
  ["rryee", "っりぇえ", "ッリェー"],
  ["rryi", "っりぃ", "ッリィ"],
  ["rryii", "っりぃい", "ッリィー"],
  ["rryo", "っりょ", "ッリョ"],
  ["rryoo", "っりょお", "ッリョー"],
  ["rryou", "っりょう", "ッリョー"],
  ["rryu", "っりゅ", "ッリュ"],
  ["rryuu", "っりゅう", "ッリュー"],
  ["rryâ", "っりゃあ", "ッラヤー"],
  ["rryê", "っりぇえ", "ッリェー"],
  ["rryî", "っりぃい", "ッリィー"],
  ["rryô", "っりょう", "ッリョー"],
  ["rryû", "っりゅう", "ッリュー"],
  ["rryā", "っりゃあ", "ッリャー"],
  ["rryē", "っりぇえ", "ッリェー"],
  ["rryī", "っりぃい", "ッリィー"],
  ["rryō", "っりょう", "ッリョー"],
  ["rryū", "っりゅう", "ッリュー"],
  ["rrâ", "っらあ", "ッラー"],
  ["rrê", "っれえ", "ッレー"],
  ["rrî", "っりい", "ッリー"],
  ["rrô", "っろう", "ッロー"],
  ["rrû", "っるう", "ッルー"],
  ["rrā", "っらあ", "ッラー"],
  ["rrē", "っれえ", "ッレー"],
  ["rrī", "っりい", "ッリー"],
  ["rrō", "っろう", "ッロー"],
  ["rrū", "っるう", "ッルー"],
  ["ru", "る", "ル"],
  ["ruu", "るう", "ルー"],
  ["rya", "りゃ", "リャ"],
  ["ryaa", "りゃあ", "リャー"],
  ["rye", "りぇ", "リェ"],
  ["ryee", "りぇえ", "リェー"],
  ["ryi", "りぃ", "リィ"],
  ["ryii", "りぃい", "リィー"],
  ["ryo", "りょ", "リョ"],
  ["ryoo", "りょお", "リョー"],
  ["ryou", "りょう", "リョー"],
  ["ryu", "りゅ", "リュ"],
  ["ryuu", "りゅう", "リュー"],
  ["ryâ", "りゃあ", "リャー"],
  ["ryê", "りぇえ", "リェー"],
  ["ryî", "りぃい", "リィー"],
  ["ryô", "りょう", "リョー"],
  ["ryû", "りゅう", "リュー"],
  ["ryā", "りゃあ", "リャー"],
  ["ryē", "りぇえ", "リェー"],
  ["ryī", "りぃい", "リィー"],
  ["ryō", "りょう", "リョー"],
  ["ryū", "りゅう", "リュー"],
  ["râ", "らあ", "ラー"],
  ["rê", "れえ", "レー"],
  ["rî", "りい", "リー"],
  ["rô", "ろう", "ロー"],
  ["rû", "るう", "ルー"],
  ["rā", "らあ", "ラー"],
  ["rē", "れえ", "レー"],
  ["rī", "りい", "リー"],
  ["rō", "ろう", "ロー"],
  ["rū", "るう", "ルー"],
  ["s", "す", "ス"],
  ["s'a", "すぁ", "スァ"],
  ["s'aa", "すぁあ", "スァー"],
  ["s'e", "すぇ", "スェ"],
  ["s'ee", "すぇえ", "スェー"],
  ["s'i", "すぃ", "スィ"],
  ["s'ii", "すぃい", "スィー"],
  ["s'o", "すぉ", "スォ"],
  ["s'oo", "すぉお", "スォー"],
  ["s'ou", "すぉう", "スォー"],
  ["s'u", "すぅ", "スゥ"],
  ["s'uu", "すぅう", "スゥー"],
  ["s'â", "すぁあ", "スァー"],
  ["s'ê", "すぇえ", "スェー"],
  ["s'î", "すぃい", "スィー"],
  ["s'ô", "すぉう", "スォー"],
  ["s'û", "すぅう", "スゥー"],
  ["s'ā", "すぁあ", "スァー"],
  ["s'ē", "すぇえ", "スェー"],
  ["s'ī", "すぃい", "スィー"],
  ["s'ō", "すぉう", "スォー"],
  ["s'ū", "すぅう", "スゥー"],
  ["sa", "さ", "サ"],
  ["saa", "さあ", "サー"],
  ["se", "せ", "セ"],
  ["see", "せえ", "セー"],
  ["sha", "しゃ", "シャ"],
  ["shaa", "しゃあ", "シャー"],
  ["she", "しぇ", "シェ"],
  ["shee", "しぇえ", "シェー"],
  ["shi", "し", "シ"],
  ["shii", "しい", "シー"],
  ["sho", "しょ", "ショ"],
  ["shoo", "しょお", "ショー"],
  ["shou", "しょう", "ショー"],
  ["shu", "しゅ", "シュ"],
  ["shuu", "しゅう", "シュー"],
  ["shâ", "しゃあ", "シャー"],
  ["shê", "しぇえ", "シェー"],
  ["shî", "しい", "シー"],
  ["shô", "しょう", "ショー"],
  ["shû", "しゅう", "シュー"],
  ["shā", "しゃあ", "シャー"],
  ["shē", "しぇえ", "シェー"],
  ["shī", "しい", "シー"],
  ["shō", "しょう", "ショー"],
  ["shū", "しゅう", "シュー"],
  ["si", "し", "シ"],
  ["sii", "しい", "シー"],
  ["so", "そ", "ソ"],
  ["soo", "そお", "ソー"],
  ["sou", "そう", "ソー"],
  ["ss", "っす", "ッス"],
  ["ss'a", "っすぁ", "ッスァ"],
  ["ss'aa", "っすぁあ", "ッスァー"],
  ["ss'e", "っすぇ", "ッスェ"],
  ["ss'ee", "っすぇえ", "ッスェー"],
  ["ss'i", "っすぃ", "ッスぃ"],
  ["ss'ii", "っすぃい", "ッスぃー"],
  ["ss'o", "っすぉ", "ッスォ"],
  ["ss'oo", "っすぉお", "ッスォー"],
  ["ss'ou", "っすぉう", "ッスォー"],
  ["ss'u", "っすぅ", "ッスゥ"],
  ["ss'uu", "っすぅう", "ッスゥー"],
  ["ss'â", "っすぁあ", "ッスァー"],
  ["ss'ê", "っすぇえ", "ッスェー"],
  ["ss'î", "っすぃい", "ッスぃー"],
  ["ss'ô", "っすぉう", "ッスォー"],
  ["ss'û", "っすぅう", "ッスゥー"],
  ["ss'ā", "っすぁあ", "ッスァー"],
  ["ss'ē", "っすぇえ", "ッスェー"],
  ["ss'ī", "っすぃい", "ッスぃー"],
  ["ss'ō", "っすぉう", "ッスォー"],
  ["ss'ū", "っすぅう", "ッスゥー"],
  ["ssa", "っさ", "ッサ"],
  ["ssaa", "っさあ", "ッサー"],
  ["sse", "っせ", "ッセ"],
  ["ssee", "っせえ", "ッセー"],
  ["ssha", "っしゃ", "ッシャ"],
  ["sshaa", "っしゃあ", "ッシャー"],
  ["sshe", "っしぇ", "ッシェ"],
  ["sshee", "っしぇえ", "ッシェー"],
  ["sshi", "っし", "ッシ"],
  ["sshii", "っしい", "ッシー"],
  ["ssho", "っしょ", "ッショ"],
  ["sshoo", "っしょお", "ッショー"],
  ["sshou", "っしょう", "ッショー"],
  ["sshu", "っしゅ", "ッシュ"],
  ["sshuu", "っしゅう", "ッシュー"],
  ["sshâ", "っしゃあ", "ッシャー"],
  ["sshê", "っしぇえ", "ッシェー"],
  ["sshî", "っしい", "ッシー"],
  ["sshô", "っしょう", "ッショー"],
  ["sshû", "っしゅう", "ッシュー"],
  ["sshā", "っしゃあ", "ッシャー"],
  ["sshē", "っしぇえ", "ッシェー"],
  ["sshī", "っしい", "ッシー"],
  ["sshō", "っしょう", "ッショー"],
  ["sshū", "っしゅう", "ッシュー"],
  ["ssi", "っし", "ッシ"],
  ["ssii", "っしい", "ッシー"],
  ["sso", "っそ", "ッソ"],
  ["ssoo", "っそお", "ッソー"],
  ["ssou", "っそう", "ッソー"],
  ["ssu", "っす", "ッス"],
  ["ssuu", "っすう", "ッスー"],
  ["ssya", "っしゃ", "ッシャ"],
  ["ssyaa", "っしゃあ", "ッシャー"],
  ["ssye", "っしぇ", "ッシェ"],
  ["ssyee", "っしぇえ", "ッシェー"],
  ["ssyi", "っしぃ", "ッシィ"],
  ["ssyii", "っしぃい", "ッシィー"],
  ["ssyo", "っしょ", "ッショ"],
  ["ssyoo", "っしょお", "ッショー"],
  ["ssyou", "っしょう", "ッショー"],
  ["ssyu", "っしゅ", "ッシュ"],
  ["ssyuu", "っしゅう", "ッシュー"],
  ["ssyâ", "っしゃあ", "ッシャー"],
  ["ssyê", "っしぇえ", "ッシェー"],
  ["ssyî", "っしぃい", "ッシィー"],
  ["ssyô", "っしょう", "ッショー"],
  ["ssyû", "っしゅう", "ッシュー"],
  ["ssyā", "っしゃあ", "ッシャー"],
  ["ssyē", "っしぇえ", "ッシェー"],
  ["ssyī", "っしぃい", "ッシィー"],
  ["ssyō", "っしょう", "ッショー"],
  ["ssyū", "っしゅう", "ッシュー"],
  ["ssâ", "っさあ", "ッサー"],
  ["ssê", "っせえ", "ッセー"],
  ["ssî", "っしい", "ッシー"],
  ["ssô", "っそう", "ッソー"],
  ["ssû", "っすう", "ッスー"],
  ["ssā", "っさあ", "ッサー"],
  ["ssē", "っせえ", "ッセー"],
  ["ssī", "っしい", "ッシー"],
  ["ssō", "っそう", "ッソー"],
  ["ssū", "っすう", "ッスー"],
  ["su", "す", "ス"],
  ["suu", "すう", "スー"],
  ["sya", "しゃ", "シャ"],
  ["syaa", "しゃあ", "シャー"],
  ["sye", "しぇ", "シェ"],
  ["syee", "しぇえ", "シェー"],
  ["syi", "しぃ", "シィ"],
  ["syii", "しぃい", "シィー"],
  ["syo", "しょ", "ショ"],
  ["syoo", "しょお", "ショー"],
  ["syou", "しょう", "ショー"],
  ["syu", "しゅ", "シュ"],
  ["syuu", "しゅう", "シュー"],
  ["syâ", "しゃあ", "シャー"],
  ["syê", "しぇえ", "シェー"],
  ["syî", "しぃい", "シィー"],
  ["syô", "しょう", "ショー"],
  ["syû", "しゅう", "シュー"],
  ["syā", "しゃあ", "シャー"],
  ["syē", "しぇえ", "シェー"],
  ["syī", "しぃい", "シィー"],
  ["syō", "しょう", "ショー"],
  ["syū", "しゅう", "シュー"],
  ["sâ", "さあ", "サー"],
  ["sê", "せえ", "セー"],
  ["sî", "しい", "シー"],
  ["sô", "そう", "ソー"],
  ["sû", "すう", "スー"],
  ["sā", "さあ", "サー"],
  ["sē", "せえ", "セー"],
  ["sī", "しい", "シー"],
  ["sō", "そう", "ソー"],
  ["sū", "すう", "スー"],
  ["t", "と", "ト"],
  ["t'a", "とぁ", "トァ"],
  ["t'aa", "とぁあ", "トァー"],
  ["t'e", "とぇ", "トェ"],
  ["t'ee", "とぇえ", "トェー"],
  ["t'i", "てぃ", "ティ"],
  ["t'ii", "てぃい", "ティー"],
  ["t'o", "とぉ", "トォ"],
  ["t'oo", "とぉお", "トォー"],
  ["t'ou", "とぉう", "トォー"],
  ["t'u", "とぅ", "トゥ"],
  ["t'â", "とぁあ", "トァー"],
  ["t'ê", "とぇえ", "トェー"],
  ["t'î", "てぃい", "ティー"],
  ["t'ô", "とぉう", "トォー"],
  ["t'ā", "とぁあ", "トァー"],
  ["t'ē", "とぇえ", "トェー"],
  ["t'ī", "てぃい", "ティー"],
  ["t'ō", "とぉう", "トォー"],
  ["ta", "た", "タ"],
  ["taa", "たあ", "ター"],
  ["tcha", "っちゃ", "ッチャ"],
  ["tchaa", "っちゃあ", "ッチャー"],
  ["tche", "っちぇ", "ッチェ"],
  ["tchee", "っちぇえ", "ッチェエ"],
  ["tchi", "っち", "ッチ"],
  ["tchii", "っちい", "ッチー"],
  ["tcho", "っちょ", "ッチョ"],
  ["tchoo", "っちょお", "ッチョー"],
  ["tchou", "っちょう", "ッチョー"],
  ["tchu", "っちゅ", "ッチュ"],
  ["tchuu", "っちゅう", "ッチュー"],
  ["tchâ", "っちゃあ", "ッチャー"],
  ["tchê", "っちぇえ", "ッチェエ"],
  ["tchî", "っちい", "ッチー"],
  ["tchô", "っちょう", "ッチョー"],
  ["tchû", "っちゅう", "ッチュー"],
  ["tchā", "っちゃあ", "ッチャー"],
  ["tchē", "っちぇえ", "ッチェエ"],
  ["tchī", "っちい", "ッチー"],
  ["tchō", "っちょう", "ッチョー"],
  ["tchū", "っちゅう", "ッチュー"],
  ["te", "て", "テ"],
  ["tee", "てえ", "テー"],
  ["ti", "ち", "チ"],
  ["tii", "ちい", "チー"],
  ["to", "と", "ト"],
  ["too", "とお", "トー"],
  ["tou", "とう", "トー"],
  ["tsa", "つぁ", "ツァ"],
  ["tsaa", "つぁあ", "ツァー"],
  ["tse", "つぇ", "ツェ"],
  ["tsee", "つぇえ", "ツェー"],
  ["tsi", "つぃ", "ツィ"],
  ["tsii", "つぃい", "ツィー"],
  ["tso", "つぉ", "ツォ"],
  ["tsoo", "つぉお", "ツォー"],
  ["tsou", "つぉう", "ツォー"],
  ["tsu", "つ", "ツ"],
  ["tsuu", "つう", "ツー"],
  ["tsâ", "つぁあ", "ツァー"],
  ["tsê", "つぇえ", "ツェー"],
  ["tsî", "つぃい", "ツィー"],
  ["tsô", "つぉう", "ツォー"],
  ["tsû", "つう", "ツー"],
  ["tsā", "つぁあ", "ツァー"],
  ["tsē", "つぇえ", "ツェー"],
  ["tsī", "つぃい", "ツィー"],
  ["tsō", "つぉう", "ツォー"],
  ["tsū", "つう", "ツー"],
  ["tt", "っと", "ット"],
  ["tt'a", "っとぁ", "ットァ"],
  ["tt'aa", "っとぁあ", "ットァー"],
  ["tt'e", "っとぇ", "ットェ"],
  ["tt'ee", "っとぇえ", "ットェー"],
  ["tt'i", "ってぃ", "ッティ"],
  ["tt'ii", "ってぃい", "ッティー"],
  ["tt'o", "っとぉ", "ットォ"],
  ["tt'oo", "っとぉお", "ットォー"],
  ["tt'ou", "っとぉう", "ットォー"],
  ["tt'u", "っとぅ", "ットゥ"],
  ["tt'â", "っとぁあ", "ットァー"],
  ["tt'ê", "っとぇえ", "ットェー"],
  ["tt'î", "ってぃい", "ッティー"],
  ["tt'ô", "っとぉう", "ットォー"],
  ["tt'ā", "っとぁあ", "ットァー"],
  ["tt'ē", "っとぇえ", "ットェー"],
  ["tt'ī", "ってぃい", "ッティー"],
  ["tt'ō", "っとぉう", "ットォー"],
  ["tta", "った", "ッタ"],
  ["ttaa", "ったあ", "ッター"],
  ["tte", "って", "ッテ"],
  ["ttee", "ってえ", "ッテー"],
  ["tti", "っち", "ッチ"],
  ["ttii", "っちい", "ッチー"],
  ["tto", "っと", "ット"],
  ["ttoo", "っとお", "ットー"],
  ["ttou", "っとう", "ットー"],
  ["ttsa", "っつぁ", "ッツァ"],
  ["ttsaa", "っつぁあ", "ッツァー"],
  ["ttse", "っつぇ", "ッツェ"],
  ["ttsee", "っつぇえ", "ッツェー"],
  ["ttsi", "っつぃ", "ッツィ"],
  ["ttsii", "っつぃい", "ッツィー"],
  ["ttso", "っつぉ", "ッツォ"],
  ["ttsoo", "っつぉお", "ッツォー"],
  ["ttsou", "っつぉう", "ッツォー"],
  ["ttsu", "っつ", "ッツ"],
  ["ttsuu", "っつう", "ッツー"],
  ["ttsâ", "っつぁあ", "ッツァー"],
  ["ttsê", "っつぇえ", "ッツェー"],
  ["ttsî", "っつぃい", "ッツィー"],
  ["ttsô", "っつぉう", "ッツォー"],
  ["ttsû", "っつう", "ッツー"],
  ["ttsā", "っつぁあ", "ッツァー"],
  ["ttsē", "っつぇえ", "ッツェー"],
  ["ttsī", "っつぃい", "ッツィー"],
  ["ttsō", "っつぉう", "ッツォー"],
  ["ttsū", "っつう", "ッツー"],
  ["ttu", "っつ", "ッツ"],
  ["ttuu", "っつう", "ッツー"],
  ["ttya", "っちゃ", "ッチャ"],
  ["ttyaa", "っちゃあ", "ッチャー"],
  ["ttye", "っちぇ", "ッチェ"],
  ["ttyee", "っちぇえ", "ッチェー"],
  ["ttyi", "っちぃ", "ッチィ"],
  ["ttyii", "っちぃい", "ッチィー"],
  ["ttyo", "っちょ", "ッチョ"],
  ["ttyoo", "っちょお", "ッチョー"],
  ["ttyou", "っちょう", "ッチョー"],
  ["ttyu", "っちゅ", "ッチュ"],
  ["ttyuu", "っちゅう", "ッチュー"],
  ["ttyâ", "っちゃあ", "ッチャー"],
  ["ttyê", "っちぇえ", "ッチェー"],
  ["ttyî", "っちぃい", "ッチィー"],
  ["ttyô", "っちょう", "ッチョー"],
  ["ttyû", "っちゅう", "ッチュー"],
  ["ttyā", "っちゃあ", "ッチャー"],
  ["ttyē", "っちぇえ", "ッチェー"],
  ["ttyī", "っちぃい", "ッチィー"],
  ["ttyō", "っちょう", "ッチョー"],
  ["ttyū", "っちゅう", "ッチュー"],
  ["ttâ", "ったあ", "ッター"],
  ["ttê", "ってえ", "ッテー"],
  ["ttî", "っちい", "ッチー"],
  ["ttô", "っとう", "ットー"],
  ["ttû", "っつう", "ッツー"],
  ["ttā", "ったあ", "ッター"],
  ["ttē", "ってえ", "ッテー"],
  ["ttī", "っちい", "ッチー"],
  ["ttō", "っとう", "ットー"],
  ["ttū", "っつう", "ッツー"],
  ["tu", "つ", "ツ"],
  ["tuu", "つう", "ツー"],
  ["tya", "ちゃ", "チャ"],
  ["tyaa", "ちゃあ", "チャー"],
  ["tye", "ちぇ", "チェ"],
  ["tyee", "ちぇえ", "チェー"],
  ["tyi", "ちぃ", "チィ"],
  ["tyii", "ちぃい", "チィー"],
  ["tyo", "ちょ", "チョ"],
  ["tyoo", "ちょお", "チョー"],
  ["tyou", "ちょう", "チョー"],
  ["tyu", "ちゅ", "チュ"],
  ["tyuu", "ちゅう", "チュー"],
  ["tyâ", "ちゃあ", "チャー"],
  ["tyê", "ちぇえ", "チェー"],
  ["tyî", "ちぃい", "チィー"],
  ["tyô", "ちょう", "チョー"],
  ["tyû", "ちゅう", "チュー"],
  ["tyā", "ちゃあ", "チャー"],
  ["tyē", "ちぇえ", "チェー"],
  ["tyī", "ちぃい", "チィー"],
  ["tyō", "ちょう", "チョー"],
  ["tyū", "ちゅう", "チュー"],
  ["tâ", "たあ", "ター"],
  ["tê", "てえ", "テー"],
  ["tî", "ちい", "チー"],
  ["tô", "とう", "トー"],
  ["tû", "つう", "ツー"],
  ["tā", "たあ", "ター"],
  ["tē", "てえ", "テー"],
  ["tī", "ちい", "チー"],
  ["tō", "とう", "トー"],
  ["tū", "つう", "ツー"],
  ["u", "う", "ウ"],
  ["uu", "うう", "ウー"],
  ["v", "ゔ", "ヴ"],
  ["va", "ゔぁ", "ヴァ"],
  ["vaa", "ゔぁあ", "ヴァー"],
  ["ve", "ゔぇ", "ヴェ"],
  ["vee", "ゔぇえ", "ヴェー"],
  ["vi", "ゔぃ", "ヴィ"],
  ["vii", "ゔぃい", "ヴィー"],
  ["vo", "ゔぉ", "ヴォ"],
  ["voo", "ゔぉお", "ヴォー"],
  ["vou", "ゔぉう", "ヴォー"],
  ["vu", "ゔ", "ヴ"],
  ["vuu", "ゔう", "ヴー"],
  ["vv", "っゔ", "ッヴ"],
  ["vva", "っゔぁ", "ッヴァ"],
  ["vvaa", "っゔぁあ", "ッヴァー"],
  ["vve", "っゔぇ", "ッヴェ"],
  ["vvee", "っゔぇえ", "ッヴェー"],
  ["vvi", "っゔぃ", "ッヴィ"],
  ["vvii", "っゔぃい", "ッヴィー"],
  ["vvo", "っゔぉ", "ッヴォ"],
  ["vvoo", "っゔぉお", "ッヴォー"],
  ["vvou", "っゔぉう", "ッヴォー"],
  ["vvu", "っゔ", "ッヴ"],
  ["vvuu", "っゔう", "ッヴー"],
  ["vvâ", "っゔぁあ", "ッヴァー"],
  ["vvê", "っゔぇえ", "ッヴェー"],
  ["vvî", "っゔぃい", "ッヴィー"],
  ["vvô", "っゔぉう", "ッヴォー"],
  ["vvû", "っゔう", "ッヴー"],
  ["vvā", "っゔぁあ", "ッヴァー"],
  ["vvē", "っゔぇえ", "ッヴェー"],
  ["vvī", "っゔぃい", "ッヴィー"],
  ["vvō", "っゔぉう", "ッヴォー"],
  ["vvū", "っゔう", "ッヴー"],
  ["vâ", "ゔぁあ", "ヴァー"],
  ["vê", "ゔぇえ", "ヴェー"],
  ["vî", "ゔぃい", "ヴィー"],
  ["vô", "ゔぉう", "ヴォー"],
  ["vû", "ゔう", "ヴー"],
  ["vā", "ゔぁあ", "ヴァー"],
  ["vē", "ゔぇえ", "ヴェー"],
  ["vī", "ゔぃい", "ヴィー"],
  ["vō", "ゔぉう", "ヴォー"],
  ["vū", "ゔう", "ヴー"],
  ["w", "わ", "ワ"],
  ["w'a", "うぁ", "ウァ"],
  ["w'aa", "うぁあ", "ウァー"],
  ["w'e", "うぇ", "ウェ"],
  ["w'ee", "うぇえ", "ウェー"],
  ["w'i", "うぃ", "ウィ"],
  ["w'ii", "うぃい", "ウィー"],
  ["w'o", "うぉ", "ウォ"],
  ["w'oo", "うぉお", "ウォー"],
  ["w'ou", "うぉう", "ウォー"],
  ["w'u", "うぅ", "ウゥ"],
  ["w'uu", "うぅう", "ウゥー"],
  ["w'â", "うぁあ", "ウァー"],
  ["w'ê", "うぇえ", "ウェー"],
  ["w'î", "うぃい", "ウィー"],
  ["w'ô", "うぉう", "ウォー"],
  ["w'û", "うぅう", "ウゥー"],
  ["w'ā", "うぁあ", "ウァー"],
  ["w'ē", "うぇえ", "ウェー"],
  ["w'ī", "うぃい", "ウィー"],
  ["w'ō", "うぉう", "ウォー"],
  ["w'ū", "うぅう", "ウゥー"],
  ["wa", "わ", "ワ"],
  ["waa", "わあ", "ワー"],
  ["we", "ゑ", "ヱ"],
  ["wee", "ゑえ", "ヱー"],
  ["wi", "ゐ", "ヰ"],
  ["wii", "ゐい", "ヰー"],
  ["wo", "を", "ヲ"],
  ["woo", "をお", "ヲー"],
  ["wou", "をう", "ヲー"],
  ["wu", "うぅ", "ウゥ"],
  ["wuu", "うぅう", "ウゥー"],
  ["ww", "っわ", "ッワ"],
  ["ww'a", "っうぁ", "ッウァ"],
  ["ww'aa", "っうぁあ", "ッウァー"],
  ["ww'e", "っうぇ", "ッウェ"],
  ["ww'ee", "っうぇえ", "ッウェー"],
  ["ww'i", "っうぃ", "ッウィ"],
  ["ww'ii", "っうぃい", "ッウィー"],
  ["ww'o", "っうぉ", "ッウォ"],
  ["ww'oo", "っうぉお", "ッウォー"],
  ["ww'ou", "っうぉう", "ッウォー"],
  ["ww'u", "っうぅ", "ッウゥ"],
  ["ww'uu", "っうぅう", "ッウゥー"],
  ["ww'â", "っうぁあ", "ッウァー"],
  ["ww'ê", "っうぇえ", "ッウェー"],
  ["ww'î", "っうぃい", "ッウィー"],
  ["ww'ô", "っうぉう", "ッウォー"],
  ["ww'û", "っうぅう", "ッウゥー"],
  ["ww'ā", "っうぁあ", "ッウァー"],
  ["ww'ē", "っうぇえ", "ッウェー"],
  ["ww'ī", "っうぃい", "ッウィー"],
  ["ww'ō", "っうぉう", "ッウォー"],
  ["ww'ū", "っうぅう", "ッウゥー"],
  ["wwa", "っわ", "ッワ"],
  ["wwaa", "っわあ", "ッワー"],
  ["wwe", "っゑ", "ッヱ"],
  ["wwee", "っゑえ", "ッヱー"],
  ["wwi", "っゐ", "ッヰ"],
  ["wwii", "っゐい", "ッヰー"],
  ["wwo", "っを", "ッヲ"],
  ["wwoo", "っをお", "ッヲー"],
  ["wwou", "っをう", "ッヲー"],
  ["wwu", "っうぅ", "ッウゥ"],
  ["wwuu", "っうぅう", "ッウゥー"],
  ["wwâ", "っわあ", "ッワー"],
  ["wwê", "っゑえ", "ッヱー"],
  ["wwî", "っゐい", "ッヰー"],
  ["wwô", "っをう", "ッヲー"],
  ["wwû", "っうぅう", "ッウゥー"],
  ["wwā", "っわあ", "ッワー"],
  ["wwē", "っゑえ", "ッヱー"],
  ["wwī", "っゐい", "ッヰー"],
  ["wwō", "っをう", "ッヲー"],
  ["wwū", "っうぅう", "ッウゥー"],
  ["wâ", "わあ", "ワー"],
  ["wê", "ゑえ", "ヱー"],
  ["wî", "ゐい", "ヰー"],
  ["wô", "をう", "ヲー"],
  ["wû", "うぅう", "ウゥー"],
  ["wā", "わあ", "ワー"],
  ["wē", "ゑえ", "ヱー"],
  ["wī", "ゐい", "ヰー"],
  ["wō", "をう", "ヲー"],
  ["wū", "うぅう", "ウゥー"],
  ["x", "くす", "クス"],
  ["x'a", "きさ", "キサ"],
  ["x'aa", "きさあ", "キサー"],
  ["x'e", "きせ", "キセ"],
  ["x'ee", "きせえ", "キセー"],
  ["x'i", "きし", "キシ"],
  ["x'ii", "きしい", "キシー"],
  ["x'o", "きそ", "キソ"],
  ["x'oo", "きそお", "キソー"],
  ["x'ou", "きそう", "キソー"],
  ["x'u", "きす", "キス"],
  ["x'uu", "きすう", "キスー"],
  ["x'â", "きさあ", "キサー"],
  ["x'ê", "きせえ", "キセー"],
  ["x'î", "きしい", "キシー"],
  ["x'ô", "きそう", "キソー"],
  ["x'û", "きすう", "キスー"],
  ["x'ā", "きさあ", "キサー"],
  ["x'ē", "きせえ", "キセー"],
  ["x'ī", "きしい", "キシー"],
  ["x'ō", "きそう", "キソー"],
  ["x'ū", "きすう", "キスー"],
  ["xa", "ぁ", "ァ"],
  ["xe", "ぇ", "ェ"],
  ["xi", "ぃ", "ィ"],
  ["xka", "ヵ", "ヵ"],
  ["xke", "ヶ", "ヶ"],
  ["xo", "ぉ", "ォ"],
  ["xtsu", "っ", "ッ"],
  ["xtu", "っ", "ッ"],
  ["xu", "ぅ", "ゥ"],
  ["xx", "っくす", "ックス"],
  ["xx'a", "っきさ", "ッキサ"],
  ["xx'aa", "っきさあ", "ッキサー"],
  ["xx'e", "っきせ", "ッキセ"],
  ["xx'ee", "っきせえ", "ッキセー"],
  ["xx'i", "っきし", "ッキシ"],
  ["xx'ii", "っきしい", "ッキシー"],
  ["xx'o", "っきそ", "ッキソ"],
  ["xx'oo", "っきそお", "ッキソー"],
  ["xx'ou", "っきそう", "ッキソー"],
  ["xx'u", "っきす", "ッキス"],
  ["xx'uu", "っきすう", "ッキスー"],
  ["xx'â", "っきさあ", "ッキサー"],
  ["xx'ê", "っきせえ", "ッキセー"],
  ["xx'î", "っきしい", "ッキシー"],
  ["xx'ô", "っきそう", "ッキソー"],
  ["xx'û", "っきすう", "ッキスー"],
  ["xx'ā", "っきさあ", "ッキサー"],
  ["xx'ē", "っきせえ", "ッキセー"],
  ["xx'ī", "っきしい", "ッキシー"],
  ["xx'ō", "っきそう", "ッキソー"],
  ["xx'ū", "っきすう", "ッキスー"],
  ["xya", "ゃ", "ャ"],
  ["xyo", "ょ", "ョ"],
  ["xyu", "ゅ", "ュ"],
  ["y", "ゆ", "ユ"],
  ["ya", "や", "ヤ"],
  ["yaa", "やあ", "ヤー"],
  ["ye", "いぇ", "イェ"],
  ["yee", "いぇえ", "イェー"],
  ["yi", "いぃ", "イィ"],
  ["yii", "いぃい", "イィー"],
  ["yo", "よ", "ヨ"],
  ["yoo", "よお", "ヨー"],
  ["you", "よう", "ヨー"],
  ["yu", "ゆ", "ユ"],
  ["yuu", "ゆう", "ユー"],
  ["yy", "っゆ", "ッユ"],
  ["yya", "っや", "ッヤ"],
  ["yyaa", "っやあ", "ッヤー"],
  ["yye", "っいぇ", "ッイェ"],
  ["yyee", "っいぇえ", "ッイェー"],
  ["yyi", "っいぃ", "ッイィ"],
  ["yyii", "っいぃい", "ッイィー"],
  ["yyo", "っよ", "ッヨ"],
  ["yyoo", "っよお", "ッヨー"],
  ["yyou", "っよう", "ッヨー"],
  ["yyu", "っゆ", "ッユ"],
  ["yyuu", "っゆう", "ッユー"],
  ["yyâ", "っやあ", "ッヤー"],
  ["yyê", "っいぇえ", "ッイェー"],
  ["yyî", "っいぃい", "ッイィー"],
  ["yyô", "っよう", "ッヨー"],
  ["yyû", "っゆう", "ッユー"],
  ["yyā", "っやあ", "ッヤー"],
  ["yyē", "っいぇえ", "ッイェー"],
  ["yyī", "っいぃい", "ッイィー"],
  ["yyō", "っよう", "ッヨー"],
  ["yyū", "っゆう", "ッユー"],
  ["yâ", "やあ", "ヤー"],
  ["yê", "いぇえ", "イェー"],
  ["yî", "いぃい", "イィー"],
  ["yô", "よう", "ヨー"],
  ["yû", "ゆう", "ユー"],
  ["yā", "やあ", "ヤー"],
  ["yē", "いぇえ", "イェー"],
  ["yī", "いぃい", "イィー"],
  ["yō", "よう", "ヨー"],
  ["yū", "ゆう", "ユー"],
  ["z", "ず", "ズ"],
  ["za", "ざ", "ザ"],
  ["zaa", "ざあ", "ザー"],
  ["ze", "ぜ", "ゼ"],
  ["zee", "ぜえ", "ゼー"],
  ["zi", "じ", "ジ"],
  ["zii", "じい", "ジー"],
  ["zo", "ぞ", "ゾ"],
  ["zoo", "ぞお", "ゾー"],
  ["zou", "ぞう", "ゾー"],
  ["zu", "ず", "ズ"],
  ["zuu", "ずう", "ズー"],
  ["zz", "っず", "ッズ"],
  ["zza", "っざ", "ッザ"],
  ["zzaa", "っざあ", "ッザー"],
  ["zze", "っぜ", "ッゼ"],
  ["zzee", "っぜえ", "ッゼー"],
  ["zzi", "っじ", "ッジ"],
  ["zzii", "っじい", "ッジー"],
  ["zzo", "っぞ", "ッゾ"],
  ["zzoo", "っぞお", "ッゾー"],
  ["zzou", "っぞう", "ッゾー"],
  ["zzu", "っず", "ッズ"],
  ["zzuu", "っずう", "ッズー"],
  ["zzâ", "っざあ", "ッザー"],
  ["zzê", "っぜえ", "ッゼー"],
  ["zzî", "っじい", "ッジー"],
  ["zzô", "っぞう", "ッゾー"],
  ["zzû", "っずう", "ッズー"],
  ["zzā", "っざあ", "ッザー"],
  ["zzē", "っぜえ", "ッゼー"],
  ["zzī", "っじい", "ッジー"],
  ["zzō", "っぞう", "ッゾー"],
  ["zzū", "っずう", "ッズー"],
  ["zâ", "ざあ", "ザー"],
  ["zê", "ぜえ", "ゼー"],
  ["zî", "じい", "ジー"],
  ["zô", "ぞう", "ゾー"],
  ["zû", "ずう", "ズー"],
  ["zā", "ざあ", "ザー"],
  ["zē", "ぜえ", "ゼー"],
  ["zī", "じい", "ジー"],
  ["zō", "ぞう", "ゾー"],
  ["zū", "ずう", "ズー"],
  ["â", "ああ", "アー"],
  ["ê", "ええ", "エー"],
  ["î", "いい", "イイ"],
  ["ô", "おう", "オー"],
  ["û", "うう", "ウー"],
  ["ā", "ああ", "アー"],
  ["ē", "ええ", "エー"],
  ["ī", "いい", "イイ"],
  ["ō", "おう", "オー"],
  ["ū", "うう", "ウー"],
  ["[", "「", "「"],
  ["]", "」", "」"],
  ["ー", "ー", "ー"]
]

hashd = {}
maxlen = 0
for i in romajitable:
    hashd[i[0]] = {}
    hashd[i[0]]['hiragana'] = i[1]
    hashd[i[0]]['katakana'] = i[2]

    if maxlen < len(i[0]):
        maxlen = len(i[0])

def substring(l, ids, ide):
    try:
        return l[ids:ide]
    except IndexError:
        return None

def to_kana(word):
    romaji = word.lower()
    hiragana = ""
    katakana = ""
    pos = 0
    while (pos < len(romaji)):
        length = maxlen
        if len(romaji)-pos<length:
            length = len(romaji)-pos
        
        found = False
        while(length > 0 and not found):
            lol_str = substring(romaji, pos, pos+length)
            obj = hashd.get(lol_str, None)
            if obj:
                hiragana+=obj['hiragana']
                katakana+=obj['katakana']
                pos+=length
                found = True
            length-=1

        if not found:
            hiragana+=romaji[pos]
            katakana+=romaji[pos]
            pos+=1

    return RomajiWord(hiragana, katakana)
